---
title: Economy
id: economy
layout: default.haml
author: Henry David Thoreau
date: 2018-04-15
chapter: 1
kind: article
---

## Economy

When I wrote the following pages, or rather the bulk of them, I lived
alone, in the woods, a mile from any neighbor, in a house which I had
built myself, on the shore of Walden Pond, in Concord, Massachusetts,
and earned my living by the labor of my hands only. I lived there two
years and two months. At present I am a sojourner in civilized life
again.

I should not obtrude my affairs so much on the notice of my readers if
very particular inquiries had not been made by my townsmen concerning
my mode of life, which some would call impertinent, though they do not
appear to me at all impertinent, but, considering the circumstances,
very natural and pertinent. Some have asked what I got to eat; if I did
not feel lonesome; if I was not afraid; and the like. Others have been
curious to learn what portion of my income I devoted to charitable
purposes; and some, who have large families, how many poor children I
maintained. I will therefore ask those of my readers who feel no
particular interest in me to pardon me if I undertake to answer some of
these questions in this book. In most books, the _I_, or first person,
is omitted; in this it will be retained; that, in respect to egotism,
is the main difference. We commonly do not remember that it is, after
all, always the first person that is speaking. I should not talk so
much about myself if there were anybody else whom I knew as well.
Unfortunately, I am confined to this theme by the narrowness of my
experience. Moreover, I, on my side, require of every writer, first or
last, a simple and sincere account of his own life, and not merely what
he has heard of other men’s lives; some such account as he would send
to his kindred from a distant land; for if he has lived sincerely, it
must have been in a distant land to me. Perhaps these pages are more
particularly addressed to poor students. As for the rest of my readers,
they will accept such portions as apply to them. I trust that none will
stretch the seams in putting on the coat, for it may do good service to
him whom it fits.

I would fain say something, not so much concerning the Chinese and
Sandwich Islanders as you who read these pages, who are said to live in
New England; something about your condition, especially your outward
condition or circumstances in this world, in this town, what it is,
whether it is necessary that it be as bad as it is, whether it cannot
be improved as well as not. I have travelled a good deal in Concord;
and everywhere, in shops, and offices, and fields, the inhabitants have
appeared to me to be doing penance in a thousand remarkable ways. What
I have heard of Brahmins sitting exposed to four fires and looking in
the face of the sun; or hanging suspended, with their heads downward,
over flames; or looking at the heavens over their shoulders “until it
becomes impossible for them to resume their natural position, while
from the twist of the neck nothing but liquids can pass into the
stomach;” or dwelling, chained for life, at the foot of a tree; or
measuring with their bodies, like caterpillars, the breadth of vast
empires; or standing on one leg on the tops of pillars,—even these
forms of conscious penance are hardly more incredible and astonishing
than the scenes which I daily witness. The twelve labors of Hercules
were trifling in comparison with those which my neighbors have
undertaken; for they were only twelve, and had an end; but I could
never see that these men slew or captured any monster or finished any
labor. They have no friend Iolas to burn with a hot iron the root of
the hydra’s head, but as soon as one head is crushed, two spring up.

I see young men, my townsmen, whose misfortune it is to have inherited
farms, houses, barns, cattle, and farming tools; for these are more
easily acquired than got rid of. Better if they had been born in the
open pasture and suckled by a wolf, that they might have seen with
clearer eyes what field they were called to labor in. Who made them
serfs of the soil? Why should they eat their sixty acres, when man is
condemned to eat only his peck of dirt? Why should they begin digging
their graves as soon as they are born? They have got to live a man’s
life, pushing all these things before them, and get on as well as they
can. How many a poor immortal soul have I met well nigh crushed and
smothered under its load, creeping down the road of life, pushing
before it a barn seventy-five feet by forty, its Augean stables never
cleansed, and one hundred acres of land, tillage, mowing, pasture, and
wood-lot! The portionless, who struggle with no such unnecessary
inherited encumbrances, find it labor enough to subdue and cultivate a
few cubic feet of flesh.

But men labor under a mistake. The better part of the man is soon
plowed into the soil for compost. By a seeming fate, commonly called
necessity, they are employed, as it says in an old book, laying up
treasures which moth and rust will corrupt and thieves break through
and steal. It is a fool’s life, as they will find when they get to the
end of it, if not before. It is said that Deucalion and Pyrrha created
men by throwing stones over their heads behind them:—

     Inde genus durum sumus, experiensque laborum,
     Et documenta damus quâ simus origine nati.

Or, as Raleigh rhymes it in his sonorous way,—

     “From thence our kind hard-hearted is, enduring pain and care,
     Approving that our bodies of a stony nature are.”

So much for a blind obedience to a blundering oracle, throwing the
stones over their heads behind them, and not seeing where they fell.

Most men, even in this comparatively free country, through mere
ignorance and mistake, are so occupied with the factitious cares and
superfluously coarse labors of life that its finer fruits cannot be
plucked by them. Their fingers, from excessive toil, are too clumsy and
tremble too much for that. Actually, the laboring man has not leisure
for a true integrity day by day; he cannot afford to sustain the
manliest relations to men; his labor would be depreciated in the
market. He has no time to be anything but a machine. How can he
remember well his ignorance—which his growth requires—who has so often
to use his knowledge? We should feed and clothe him gratuitously
sometimes, and recruit him with our cordials, before we judge of him.
The finest qualities of our nature, like the bloom on fruits, can be
preserved only by the most delicate handling. Yet we do not treat
ourselves nor one another thus tenderly.

Some of you, we all know, are poor, find it hard to live, are
sometimes, as it were, gasping for breath. I have no doubt that some of
you who read this book are unable to pay for all the dinners which you
have actually eaten, or for the coats and shoes which are fast wearing
or are already worn out, and have come to this page to spend borrowed
or stolen time, robbing your creditors of an hour. It is very evident
what mean and sneaking lives many of you live, for my sight has been
whetted by experience; always on the limits, trying to get into
business and trying to get out of debt, a very ancient slough, called
by the Latins _æs alienum_, another’s brass, for some of their coins
were made of brass; still living, and dying, and buried by this other’s
brass; always promising to pay, promising to pay, tomorrow, and dying
today, insolvent; seeking to curry favor, to get custom, by how many
modes, only not state-prison offences; lying, flattering, voting,
contracting yourselves into a nutshell of civility or dilating into an
atmosphere of thin and vaporous generosity, that you may persuade your
neighbor to let you make his shoes, or his hat, or his coat, or his
carriage, or import his groceries for him; making yourselves sick, that
you may lay up something against a sick day, something to be tucked
away in an old chest, or in a stocking behind the plastering, or, more
safely, in the brick bank; no matter where, no matter how much or how
little.

I sometimes wonder that we can be so frivolous, I may almost say, as to
attend to the gross but somewhat foreign form of servitude called Negro
Slavery, there are so many keen and subtle masters that enslave both
north and south. It is hard to have a southern overseer; it is worse to
have a northern one; but worst of all when you are the slave-driver of
yourself. Talk of a divinity in man! Look at the teamster on the
highway, wending to market by day or night; does any divinity stir
within him? His highest duty to fodder and water his horses! What is
his destiny to him compared with the shipping interests? Does not he
drive for Squire Make-a-stir? How godlike, how immortal, is he? See how
he cowers and sneaks, how vaguely all the day he fears, not being
immortal nor divine, but the slave and prisoner of his own opinion of
himself, a fame won by his own deeds. Public opinion is a weak tyrant
compared with our own private opinion. What a man thinks of himself,
that it is which determines, or rather indicates, his fate.
Self-emancipation even in the West Indian provinces of the fancy and
imagination,—what Wilberforce is there to bring that about? Think,
also, of the ladies of the land weaving toilet cushions against the
last day, not to betray too green an interest in their fates! As if you
could kill time without injuring eternity.

The mass of men lead lives of quiet desperation. What is called
resignation is confirmed desperation. From the desperate city you go
into the desperate country, and have to console yourself with the
bravery of minks and muskrats. A stereotyped but unconscious despair is
concealed even under what are called the games and amusements of
mankind. There is no play in them, for this comes after work. But it is
a characteristic of wisdom not to do desperate things.

When we consider what, to use the words of the catechism, is the chief
end of man, and what are the true necessaries and means of life, it
appears as if men had deliberately chosen the common mode of living
because they preferred it to any other. Yet they honestly think there
is no choice left. But alert and healthy natures remember that the sun
rose clear. It is never too late to give up our prejudices. No way of
thinking or doing, however ancient, can be trusted without proof. What
everybody echoes or in silence passes by as true to-day may turn out to
be falsehood to-morrow, mere smoke of opinion, which some had trusted
for a cloud that would sprinkle fertilizing rain on their fields. What
old people say you cannot do you try and find that you can. Old deeds
for old people, and new deeds for new. Old people did not know enough
once, perchance, to fetch fresh fuel to keep the fire a-going; new
people put a little dry wood under a pot, and are whirled round the
globe with the speed of birds, in a way to kill old people, as the
phrase is. Age is no better, hardly so well, qualified for an
instructor as youth, for it has not profited so much as it has lost.
One may almost doubt if the wisest man has learned any thing of
absolute value by living. Practically, the old have no very important
advice to give the young, their own experience has been so partial, and
their lives have been such miserable failures, for private reasons, as
they must believe; and it may be that they have some faith left which
belies that experience, and they are only less young than they were. I
have lived some thirty years on this planet, and I have yet to hear the
first syllable of valuable or even earnest advice from my seniors. They
have told me nothing, and probably cannot tell me any thing to the
purpose. Here is life, an experiment to a great extent untried by me;
but it does not avail me that they have tried it. If I have any
experience which I think valuable, I am sure to reflect that this my
Mentors said nothing about.

One farmer says to me, “You cannot live on vegetable food solely, for
it furnishes nothing to make bones with;” and so he religiously devotes
a part of his day to supplying his system with the raw material of
bones; walking all the while he talks behind his oxen, which, with
vegetable-made bones, jerk him and his lumbering plough along in spite
of every obstacle. Some things are really necessaries of life in some
circles, the most helpless and diseased, which in others are luxuries
merely, and in others still are entirely unknown.

The whole ground of human life seems to some to have been gone over by
their predecessors, both the heights and the valleys, and all things to
have been cared for. According to Evelyn, “the wise Solomon prescribed
ordinances for the very distances of trees; and the Roman prætors have
decided how often you may go into your neighbor’s land to gather the
acorns which fall on it without trespass, and what share belongs to
that neighbor.” Hippocrates has even left directions how we should cut
our nails; that is, even with the ends of the fingers, neither shorter
nor longer. Undoubtedly the very tedium and ennui which presume to have
exhausted the variety and the joys of life are as old as Adam. But
man’s capacities have never been measured; nor are we to judge of what
he can do by any precedents, so little has been tried. Whatever have
been thy failures hitherto, “be not afflicted, my child, for who shall
assign to thee what thou hast left undone?”

We might try our lives by a thousand simple tests; as, for instance,
that the same sun which ripens my beans illumines at once a system of
earths like ours. If I had remembered this it would have prevented some
mistakes. This was not the light in which I hoed them. The stars are
the apexes of what wonderful triangles! What distant and different
beings in the various mansions of the universe are contemplating the
same one at the same moment! Nature and human life are as various as
our several constitutions. Who shall say what prospect life offers to
another? Could a greater miracle take place than for us to look through
each other’s eyes for an instant? We should live in all the ages of the
world in an hour; ay, in all the worlds of the ages. History, Poetry,
Mythology!—I know of no reading of another’s experience so startling
and informing as this would be.

The greater part of what my neighbors call good I believe in my soul to
be bad, and if I repent of anything, it is very likely to be my good
behavior. What demon possessed me that I behaved so well? You may say
the wisest thing you can, old man,—you who have lived seventy years,
not without honor of a kind,—I hear an irresistible voice which invites
me away from all that. One generation abandons the enterprises of
another like stranded vessels.

I think that we may safely trust a good deal more than we do. We may
waive just so much care of ourselves as we honestly bestow elsewhere.
Nature is as well adapted to our weakness as to our strength. The
incessant anxiety and strain of some is a well nigh incurable form of
disease. We are made to exaggerate the importance of what work we do;
and yet how much is not done by us! or, what if we had been taken sick?
How vigilant we are! determined not to live by faith if we can avoid
it; all the day long on the alert, at night we unwillingly say our
prayers and commit ourselves to uncertainties. So thoroughly and
sincerely are we compelled to live, reverencing our life, and denying
the possibility of change. This is the only way, we say; but there are
as many ways as there can be drawn radii from one centre. All change is
a miracle to contemplate; but it is a miracle which is taking place
every instant. Confucius said, “To know that we know what we know, and
that we do not know what we do not know, that is true knowledge.” When
one man has reduced a fact of the imagination to be a fact to his
understanding, I foresee that all men at length establish their lives
on that basis.



Let us consider for a moment what most of the trouble and anxiety which
I have referred to is about, and how much it is necessary that we be
troubled, or, at least, careful. It would be some advantage to live a
primitive and frontier life, though in the midst of an outward
civilization, if only to learn what are the gross necessaries of life
and what methods have been taken to obtain them; or even to look over
the old day-books of the merchants, to see what it was that men most
commonly bought at the stores, what they stored, that is, what are the
grossest groceries. For the improvements of ages have had but little
influence on the essential laws of man’s existence; as our skeletons,
probably, are not to be distinguished from those of our ancestors.

By the words, _necessary of life_, I mean whatever, of all that man
obtains by his own exertions, has been from the first, or from long use
has become, so important to human life that few, if any, whether from
savageness, or poverty, or philosophy, ever attempt to do without it.
To many creatures there is in this sense but one necessary of life,
Food. To the bison of the prairie it is a few inches of palatable
grass, with water to drink; unless he seeks the Shelter of the forest
or the mountain’s shadow. None of the brute creation requires more than
Food and Shelter. The necessaries of life for man in this climate may,
accurately enough, be distributed under the several heads of Food,
Shelter, Clothing, and Fuel; for not till we have secured these are we
prepared to entertain the true problems of life with freedom and a
prospect of success. Man has invented, not only houses, but clothes and
cooked food; and possibly from the accidental discovery of the warmth
of fire, and the consequent use of it, at first a luxury, arose the
present necessity to sit by it. We observe cats and dogs acquiring the
same second nature. By proper Shelter and Clothing we legitimately
retain our own internal heat; but with an excess of these, or of Fuel,
that is, with an external heat greater than our own internal, may not
cookery properly be said to begin? Darwin, the naturalist, says of the
inhabitants of Tierra del Fuego, that while his own party, who were
well clothed and sitting close to a fire, were far from too warm, these
naked savages, who were farther off, were observed, to his great
surprise, “to be streaming with perspiration at undergoing such a
roasting.” So, we are told, the New Hollander goes naked with impunity,
while the European shivers in his clothes. Is it impossible to combine
the hardiness of these savages with the intellectualness of the
civilized man? According to Liebig, man’s body is a stove, and food the
fuel which keeps up the internal combustion in the lungs. In cold
weather we eat more, in warm less. The animal heat is the result of a
slow combustion, and disease and death take place when this is too
rapid; or for want of fuel, or from some defect in the draught, the
fire goes out. Of course the vital heat is not to be confounded with
fire; but so much for analogy. It appears, therefore, from the above
list, that the expression, _animal life_, is nearly synonymous with the
expression, _animal heat_; for while Food may be regarded as the Fuel
which keeps up the fire within us,—and Fuel serves only to prepare that
Food or to increase the warmth of our bodies by addition from
without,—Shelter and Clothing also serve only to retain the _heat_ thus
generated and absorbed.

The grand necessity, then, for our bodies, is to keep warm, to keep the
vital heat in us. What pains we accordingly take, not only with our
Food, and Clothing, and Shelter, but with our beds, which are our
night-clothes, robbing the nests and breasts of birds to prepare this
shelter within a shelter, as the mole has its bed of grass and leaves
at the end of its burrow! The poor man is wont to complain that this is
a cold world; and to cold, no less physical than social, we refer
directly a great part of our ails. The summer, in some climates, makes
possible to man a sort of Elysian life. Fuel, except to cook his Food,
is then unnecessary; the sun is his fire, and many of the fruits are
sufficiently cooked by its rays; while Food generally is more various,
and more easily obtained, and Clothing and Shelter are wholly or half
unnecessary. At the present day, and in this country, as I find by my
own experience, a few implements, a knife, an axe, a spade, a
wheelbarrow, &c., and for the studious, lamplight, stationery, and
access to a few books, rank next to necessaries, and can all be
obtained at a trifling cost. Yet some, not wise, go to the other side
of the globe, to barbarous and unhealthy regions, and devote themselves
to trade for ten or twenty years, in order that they may live,—that is,
keep comfortably warm,—and die in New England at last. The luxuriously
rich are not simply kept comfortably warm, but unnaturally hot; as I
implied before, they are cooked, of course _à la mode_.

Most of the luxuries, and many of the so called comforts of life, are
not only not indispensable, but positive hindrances to the elevation of
mankind. With respect to luxuries and comforts, the wisest have ever
lived a more simple and meagre life than the poor. The ancient
philosophers, Chinese, Hindoo, Persian, and Greek, were a class than
which none has been poorer in outward riches, none so rich in inward.
We know not much about them. It is remarkable that _we_ know so much of
them as we do. The same is true of the more modern reformers and
benefactors of their race. None can be an impartial or wise observer of
human life but from the vantage ground of what we should call voluntary
poverty. Of a life of luxury the fruit is luxury, whether in
agriculture, or commerce, or literature, or art. There are nowadays
professors of philosophy, but not philosophers. Yet it is admirable to
profess because it was once admirable to live. To be a philosopher is
not merely to have subtle thoughts, nor even to found a school, but so
to love wisdom as to live according to its dictates, a life of
simplicity, independence, magnanimity, and trust. It is to solve some
of the problems of life, not only theoretically, but practically. The
success of great scholars and thinkers is commonly a courtier-like
success, not kingly, not manly. They make shift to live merely by
conformity, practically as their fathers did, and are in no sense the
progenitors of a nobler race of men. But why do men degenerate ever?
What makes families run out? What is the nature of the luxury which
enervates and destroys nations? Are we sure that there is none of it in
our own lives? The philosopher is in advance of his age even in the
outward form of his life. He is not fed, sheltered, clothed, warmed,
like his contemporaries. How can a man be a philosopher and not
maintain his vital heat by better methods than other men?

When a man is warmed by the several modes which I have described, what
does he want next? Surely not more warmth of the same kind, as more and
richer food, larger and more splendid houses, finer and more abundant
clothing, more numerous incessant and hotter fires, and the like. When
he has obtained those things which are necessary to life, there is
another alternative than to obtain the superfluities; and that is, to
adventure on life now, his vacation from humbler toil having commenced.
The soil, it appears, is suited to the seed, for it has sent its
radicle downward, and it may now send its shoot upward also with
confidence. Why has man rooted himself thus firmly in the earth, but
that he may rise in the same proportion into the heavens above?—for the
nobler plants are valued for the fruit they bear at last in the air and
light, far from the ground, and are not treated like the humbler
esculents, which, though they may be biennials, are cultivated only
till they have perfected their root, and often cut down at top for this
purpose, so that most would not know them in their flowering season.

I do not mean to prescribe rules to strong and valiant natures, who
will mind their own affairs whether in heaven or hell, and perchance
build more magnificently and spend more lavishly than the richest,
without ever impoverishing themselves, not knowing how they live,—if,
indeed, there are any such, as has been dreamed; nor to those who find
their encouragement and inspiration in precisely the present condition
of things, and cherish it with the fondness and enthusiasm of
lovers,—and, to some extent, I reckon myself in this number; I do not
speak to those who are well employed, in whatever circumstances, and
they know whether they are well employed or not;—but mainly to the mass
of men who are discontented, and idly complaining of the hardness of
their lot or of the times, when they might improve them. There are some
who complain most energetically and inconsolably of any, because they
are, as they say, doing their duty. I also have in my mind that
seemingly wealthy, but most terribly impoverished class of all, who
have accumulated dross, but know not how to use it, or get rid of it,
and thus have forged their own golden or silver fetters.



If I should attempt to tell how I have desired to spend my life in
years past, it would probably surprise those of my readers who are
somewhat acquainted with its actual history; it would certainly
astonish those who know nothing about it. I will only hint at some of
the enterprises which I have cherished.

In any weather, at any hour of the day or night, I have been anxious to
improve the nick of time, and notch it on my stick too; to stand on the
meeting of two eternities, the past and future, which is precisely the
present moment; to toe that line. You will pardon some obscurities, for
there are more secrets in my trade than in most men’s, and yet not
voluntarily kept, but inseparable from its very nature. I would gladly
tell all that I know about it, and never paint “No Admittance” on my
gate.

I long ago lost a hound, a bay horse, and a turtle-dove, and am still
on their trail. Many are the travellers I have spoken concerning them,
describing their tracks and what calls they answered to. I have met one
or two who had heard the hound, and the tramp of the horse, and even
seen the dove disappear behind a cloud, and they seemed as anxious to
recover them as if they had lost them themselves.

To anticipate, not the sunrise and the dawn merely, but, if possible,
Nature herself! How many mornings, summer and winter, before yet any
neighbor was stirring about his business, have I been about mine! No
doubt, many of my townsmen have met me returning from this enterprise,
farmers starting for Boston in the twilight, or woodchoppers going to
their work. It is true, I never assisted the sun materially in his
rising, but, doubt not, it was of the last importance only to be
present at it.

So many autumn, ay, and winter days, spent outside the town, trying to
hear what was in the wind, to hear and carry it express! I well-nigh
sunk all my capital in it, and lost my own breath into the bargain,
running in the face of it. If it had concerned either of the political
parties, depend upon it, it would have appeared in the Gazette with the
earliest intelligence. At other times watching from the observatory of
some cliff or tree, to telegraph any new arrival; or waiting at evening
on the hill-tops for the sky to fall, that I might catch something,
though I never caught much, and that, manna-wise, would dissolve again
in the sun.

For a long time I was reporter to a journal, of no very wide
circulation, whose editor has never yet seen fit to print the bulk of
my contributions, and, as is too common with writers, I got only my
labor for my pains. However, in this case my pains were their own
reward.

For many years I was self-appointed inspector of snow storms and rain
storms, and did my duty faithfully; surveyor, if not of highways, then
of forest paths and all across-lot routes, keeping them open, and
ravines bridged and passable at all seasons, where the public heel had
testified to their utility.

I have looked after the wild stock of the town, which give a faithful
herdsman a good deal of trouble by leaping fences; and I have had an
eye to the unfrequented nooks and corners of the farm; though I did not
always know whether Jonas or Solomon worked in a particular field
to-day; that was none of my business. I have watered the red
huckleberry, the sand cherry and the nettle tree, the red pine and the
black ash, the white grape and the yellow violet, which might have
withered else in dry seasons.

In short, I went on thus for a long time, I may say it without
boasting, faithfully minding my business, till it became more and more
evident that my townsmen would not after all admit me into the list of
town officers, nor make my place a sinecure with a moderate allowance.
My accounts, which I can swear to have kept faithfully, I have, indeed,
never got audited, still less accepted, still less paid and settled.
However, I have not set my heart on that.

Not long since, a strolling Indian went to sell baskets at the house of
a well-known lawyer in my neighborhood. “Do you wish to buy any
baskets?” he asked. “No, we do not want any,” was the reply. “What!”
exclaimed the Indian as he went out the gate, “do you mean to starve
us?” Having seen his industrious white neighbors so well off,—that the
lawyer had only to weave arguments, and by some magic, wealth and
standing followed, he had said to himself; I will go into business; I
will weave baskets; it is a thing which I can do. Thinking that when he
had made the baskets he would have done his part, and then it would be
the white man’s to buy them. He had not discovered that it was
necessary for him to make it worth the other’s while to buy them, or at
least make him think that it was so, or to make something else which it
would be worth his while to buy. I too had woven a kind of basket of a
delicate texture, but I had not made it worth any one’s while to buy
them. Yet not the less, in my case, did I think it worth my while to
weave them, and instead of studying how to make it worth men’s while to
buy my baskets, I studied rather how to avoid the necessity of selling
them. The life which men praise and regard as successful is but one
kind. Why should we exaggerate any one kind at the expense of the
others?

Finding that my fellow-citizens were not likely to offer me any room in
the court house, or any curacy or living any where else, but I must
shift for myself, I turned my face more exclusively than ever to the
woods, where I was better known. I determined to go into business at
once, and not wait to acquire the usual capital, using such slender
means as I had already got. My purpose in going to Walden Pond was not
to live cheaply nor to live dearly there, but to transact some private
business with the fewest obstacles; to be hindered from accomplishing
which for want of a little common sense, a little enterprise and
business talent, appeared not so sad as foolish.

I have always endeavored to acquire strict business habits; they are
indispensable to every man. If your trade is with the Celestial Empire,
then some small counting house on the coast, in some Salem harbor, will
be fixture enough. You will export such articles as the country
affords, purely native products, much ice and pine timber and a little
granite, always in native bottoms. These will be good ventures. To
oversee all the details yourself in person; to be at once pilot and
captain, and owner and underwriter; to buy and sell and keep the
accounts; to read every letter received, and write or read every letter
sent; to superintend the discharge of imports night and day; to be upon
many parts of the coast almost at the same time;—often the richest
freight will be discharged upon a Jersey shore;—to be your own
telegraph, unweariedly sweeping the horizon, speaking all passing
vessels bound coastwise; to keep up a steady despatch of commodities,
for the supply of such a distant and exorbitant market; to keep
yourself informed of the state of the markets, prospects of war and
peace every where, and anticipate the tendencies of trade and
civilization,—taking advantage of the results of all exploring
expeditions, using new passages and all improvements in
navigation;—charts to be studied, the position of reefs and new lights
and buoys to be ascertained, and ever, and ever, the logarithmic tables
to be corrected, for by the error of some calculator the vessel often
splits upon a rock that should have reached a friendly pier,—there is
the untold fate of La Perouse;—universal science to be kept pace with,
studying the lives of all great discoverers and navigators, great
adventurers and merchants, from Hanno and the Phœnicians down to our
day; in fine, account of stock to be taken from time to time, to know
how you stand. It is a labor to task the faculties of a man,—such
problems of profit and loss, of interest, of tare and tret, and gauging
of all kinds in it, as demand a universal knowledge.

I have thought that Walden Pond would be a good place for business, not
solely on account of the railroad and the ice trade; it offers
advantages which it may not be good policy to divulge; it is a good
port and a good foundation. No Neva marshes to be filled; though you
must every where build on piles of your own driving. It is said that a
flood-tide, with a westerly wind, and ice in the Neva, would sweep St.
Petersburg from the face of the earth.



As this business was to be entered into without the usual capital, it
may not be easy to conjecture where those means, that will still be
indispensable to every such undertaking, were to be obtained. As for
Clothing, to come at once to the practical part of the question,
perhaps we are led oftener by the love of novelty, and a regard for the
opinions of men, in procuring it, than by a true utility. Let him who
has work to do recollect that the object of clothing is, first, to
retain the vital heat, and secondly, in this state of society, to cover
nakedness, and he may judge how much of any necessary or important work
may be accomplished without adding to his wardrobe. Kings and queens
who wear a suit but once, though made by some tailor or dressmaker to
their majesties, cannot know the comfort of wearing a suit that fits.
They are no better than wooden horses to hang the clean clothes on.
Every day our garments become more assimilated to ourselves, receiving
the impress of the wearer’s character, until we hesitate to lay them
aside, without such delay and medical appliances and some such
solemnity even as our bodies. No man ever stood the lower in my
estimation for having a patch in his clothes; yet I am sure that there
is greater anxiety, commonly, to have fashionable, or at least clean
and unpatched clothes, than to have a sound conscience. But even if the
rent is not mended, perhaps the worst vice betrayed is improvidence. I
sometimes try my acquaintances by such tests as this;—who could wear a
patch, or two extra seams only, over the knee? Most behave as if they
believed that their prospects for life would be ruined if they should
do it. It would be easier for them to hobble to town with a broken leg
than with a broken pantaloon. Often if an accident happens to a
gentleman’s legs, they can be mended; but if a similar accident happens
to the legs of his pantaloons, there is no help for it; for he
considers, not what is truly respectable, but what is respected. We
know but few men, a great many coats and breeches. Dress a scarecrow in
your last shift, you standing shiftless by, who would not soonest
salute the scarecrow? Passing a cornfield the other day, close by a hat
and coat on a stake, I recognized the owner of the farm. He was only a
little more weather-beaten than when I saw him last. I have heard of a
dog that barked at every stranger who approached his master’s premises
with clothes on, but was easily quieted by a naked thief. It is an
interesting question how far men would retain their relative rank if
they were divested of their clothes. Could you, in such a case, tell
surely of any company of civilized men, which belonged to the most
respected class? When Madam Pfeiffer, in her adventurous travels round
the world, from east to west, had got so near home as Asiatic Russia,
she says that she felt the necessity of wearing other than a travelling
dress, when she went to meet the authorities, for she “was now in a
civilized country, where —— — people are judged of by their clothes.”
Even in our democratic New England towns the accidental possession of
wealth, and its manifestation in dress and equipage alone, obtain for
the possessor almost universal respect. But they yield such respect,
numerous as they are, are so far heathen, and need to have a missionary
sent to them. Beside, clothes introduced sewing, a kind of work which
you may call endless; a woman’s dress, at least, is never done.

A man who has at length found something to do will not need to get a
new suit to do it in; for him the old will do, that has lain dusty in
the garret for an indeterminate period. Old shoes will serve a hero
longer than they have served his valet,—if a hero ever has a
valet,—bare feet are older than shoes, and he can make them do. Only
they who go to soirées and legislative halls must have new coats, coats
to change as often as the man changes in them. But if my jacket and
trousers, my hat and shoes, are fit to worship God in, they will do;
will they not? Who ever saw his old clothes,—his old coat, actually
worn out, resolved into its primitive elements, so that it was not a
deed of charity to bestow it on some poor boy, by him perchance to be
bestowed on some poorer still, or shall we say richer, who could do
with less? I say, beware of all enterprises that require new clothes,
and not rather a new wearer of clothes. If there is not a new man, how
can the new clothes be made to fit? If you have any enterprise before
you, try it in your old clothes. All men want, not something to _do
with_, but something to _do_, or rather something to _be_. Perhaps we
should never procure a new suit, however ragged or dirty the old, until
we have so conducted, so enterprised or sailed in some way, that we
feel like new men in the old, and that to retain it would be like
keeping new wine in old bottles. Our moulting season, like that of the
fowls, must be a crisis in our lives. The loon retires to solitary
ponds to spend it. Thus also the snake casts its slough, and the
caterpillar its wormy coat, by an internal industry and expansion; for
clothes are but our outmost cuticle and mortal coil. Otherwise we shall
be found sailing under false colors, and be inevitably cashiered at
last by our own opinion, as well as that of mankind.

We don garment after garment, as if we grew like exogenous plants by
addition without. Our outside and often thin and fanciful clothes are
our epidermis, or false skin, which partakes not of our life, and may
be stripped off here and there without fatal injury; our thicker
garments, constantly worn, are our cellular integument, or cortex; but
our shirts are our liber or true bark, which cannot be removed without
girdling and so destroying the man. I believe that all races at some
seasons wear something equivalent to the shirt. It is desirable that a
man be clad so simply that he can lay his hands on himself in the dark,
and that he live in all respects so compactly and preparedly, that, if
an enemy take the town, he can, like the old philosopher, walk out the
gate empty-handed without anxiety. While one thick garment is, for most
purposes, as good as three thin ones, and cheap clothing can be
obtained at prices really to suit customers; while a thick coat can be
bought for five dollars, which will last as many years, thick
pantaloons for two dollars, cowhide boots for a dollar and a half a
pair, a summer hat for a quarter of a dollar, and a winter cap for
sixty-two and a half cents, or a better be made at home at a nominal
cost, where is he so poor that, clad in such a suit, of _his own
earning_, there will not be found wise men to do him reverence?

When I ask for a garment of a particular form, my tailoress tells me
gravely, “They do not make them so now,” not emphasizing the “They” at
all, as if she quoted an authority as impersonal as the Fates, and I
find it difficult to get made what I want, simply because she cannot
believe that I mean what I say, that I am so rash. When I hear this
oracular sentence, I am for a moment absorbed in thought, emphasizing
to myself each word separately that I may come at the meaning of it,
that I may find out by what degree of consanguinity _They_ are related
to _me_, and what authority they may have in an affair which affects me
so nearly; and, finally, I am inclined to answer her with equal
mystery, and without any more emphasis of the “they,”—“It is true, they
did not make them so recently, but they do now.” Of what use this
measuring of me if she does not measure my character, but only the
breadth of my shoulders, as it were a peg to hang the coat on? We
worship not the Graces, nor the Parcæ, but Fashion. She spins and
weaves and cuts with full authority. The head monkey at Paris puts on a
traveller’s cap, and all the monkeys in America do the same. I
sometimes despair of getting anything quite simple and honest done in
this world by the help of men. They would have to be passed through a
powerful press first, to squeeze their old notions out of them, so that
they would not soon get upon their legs again, and then there would be
some one in the company with a maggot in his head, hatched from an egg
deposited there nobody knows when, for not even fire kills these
things, and you would have lost your labor. Nevertheless, we will not
forget that some Egyptian wheat was handed down to us by a mummy.

On the whole, I think that it cannot be maintained that dressing has in
this or any country risen to the dignity of an art. At present men make
shift to wear what they can get. Like shipwrecked sailors, they put on
what they can find on the beach, and at a little distance, whether of
space or time, laugh at each other’s masquerade. Every generation
laughs at the old fashions, but follows religiously the new. We are
amused at beholding the costume of Henry VIII., or Queen Elizabeth, as
much as if it was that of the King and Queen of the Cannibal Islands.
All costume off a man is pitiful or grotesque. It is only the serious
eye peering from and the sincere life passed within it, which restrain
laughter and consecrate the costume of any people. Let Harlequin be
taken with a fit of the colic and his trappings will have to serve that
mood too. When the soldier is hit by a cannon ball rags are as becoming
as purple.

The childish and savage taste of men and women for new patterns keeps
how many shaking and squinting through kaleidoscopes that they may
discover the particular figure which this generation requires today.
The manufacturers have learned that this taste is merely whimsical. Of
two patterns which differ only by a few threads more or less of a
particular color, the one will be sold readily, the other lie on the
shelf, though it frequently happens that after the lapse of a season
the latter becomes the most fashionable. Comparatively, tattooing is
not the hideous custom which it is called. It is not barbarous merely
because the printing is skin-deep and unalterable.

I cannot believe that our factory system is the best mode by which men
may get clothing. The condition of the operatives is becoming every day
more like that of the English; and it cannot be wondered at, since, as
far as I have heard or observed, the principal object is, not that
mankind may be well and honestly clad, but, unquestionably, that
corporations may be enriched. In the long run men hit only what they
aim at. Therefore, though they should fail immediately, they had better
aim at something high.



As for a Shelter, I will not deny that this is now a necessary of life,
though there are instances of men having done without it for long
periods in colder countries than this. Samuel Laing says that “the
Laplander in his skin dress, and in a skin bag which he puts over his
head and shoulders, will sleep night after night on the snow—in a
degree of cold which would extinguish the life of one exposed to it in
any woollen clothing.” He had seen them asleep thus. Yet he adds, “They
are not hardier than other people.” But, probably, man did not live
long on the earth without discovering the convenience which there is in
a house, the domestic comforts, which phrase may have originally
signified the satisfactions of the house more than of the family;
though these must be extremely partial and occasional in those climates
where the house is associated in our thoughts with winter or the rainy
season chiefly, and two thirds of the year, except for a parasol, is
unnecessary. In our climate, in the summer, it was formerly almost
solely a covering at night. In the Indian gazettes a wigwam was the
symbol of a day’s march, and a row of them cut or painted on the bark
of a tree signified that so many times they had camped. Man was not
made so large limbed and robust but that he must seek to narrow his
world, and wall in a space such as fitted him. He was at first bare and
out of doors; but though this was pleasant enough in serene and warm
weather, by daylight, the rainy season and the winter, to say nothing
of the torrid sun, would perhaps have nipped his race in the bud if he
had not made haste to clothe himself with the shelter of a house. Adam
and Eve, according to the fable, wore the bower before other clothes.
Man wanted a home, a place of warmth, or comfort, first of physical
warmth, then the warmth of the affections.

We may imagine a time when, in the infancy of the human race, some
enterprising mortal crept into a hollow in a rock for shelter. Every
child begins the world again, to some extent, and loves to stay out
doors, even in wet and cold. It plays house, as well as horse, having
an instinct for it. Who does not remember the interest with which when
young he looked at shelving rocks, or any approach to a cave? It was
the natural yearning of that portion of our most primitive ancestor
which still survived in us. From the cave we have advanced to roofs of
palm leaves, of bark and boughs, of linen woven and stretched, of grass
and straw, of boards and shingles, of stones and tiles. At last, we
know not what it is to live in the open air, and our lives are domestic
in more senses than we think. From the hearth to the field is a great
distance. It would be well perhaps if we were to spend more of our days
and nights without any obstruction between us and the celestial bodies,
if the poet did not speak so much from under a roof, or the saint dwell
there so long. Birds do not sing in caves, nor do doves cherish their
innocence in dovecots.

However, if one designs to construct a dwelling house, it behooves him
to exercise a little Yankee shrewdness, lest after all he find himself
in a workhouse, a labyrinth without a clue, a museum, an almshouse, a
prison, or a splendid mausoleum instead. Consider first how slight a
shelter is absolutely necessary. I have seen Penobscot Indians, in this
town, living in tents of thin cotton cloth, while the snow was nearly a
foot deep around them, and I thought that they would be glad to have it
deeper to keep out the wind. Formerly, when how to get my living
honestly, with freedom left for my proper pursuits, was a question
which vexed me even more than it does now, for unfortunately I am
become somewhat callous, I used to see a large box by the railroad, six
feet long by three wide, in which the laborers locked up their tools at
night, and it suggested to me that every man who was hard pushed might
get such a one for a dollar, and, having bored a few auger holes in it,
to admit the air at least, get into it when it rained and at night, and
hook down the lid, and so have freedom in his love, and in his soul be
free. This did not appear the worst, nor by any means a despicable
alternative. You could sit up as late as you pleased, and, whenever you
got up, go abroad without any landlord or house-lord dogging you for
rent. Many a man is harassed to death to pay the rent of a larger and
more luxurious box who would not have frozen to death in such a box as
this. I am far from jesting. Economy is a subject which admits of being
treated with levity, but it cannot so be disposed of. A comfortable
house for a rude and hardy race, that lived mostly out of doors, was
once made here almost entirely of such materials as Nature furnished
ready to their hands. Gookin, who was superintendent of the Indians
subject to the Massachusetts Colony, writing in 1674, says, “The best
of their houses are covered very neatly, tight and warm, with barks of
trees, slipped from their bodies at those seasons when the sap is up,
and made into great flakes, with pressure of weighty timber, when they
are green.... The meaner sort are covered with mats which they make of
a kind of bulrush, and are also indifferently tight and warm, but not
so good as the former.... Some I have seen, sixty or a hundred feet
long and thirty feet broad.... I have often lodged in their wigwams,
and found them as warm as the best English houses.” He adds, that they
were commonly carpeted and lined within with well-wrought embroidered
mats, and were furnished with various utensils. The Indians had
advanced so far as to regulate the effect of the wind by a mat
suspended over the hole in the roof and moved by a string. Such a lodge
was in the first instance constructed in a day or two at most, and
taken down and put up in a few hours; and every family owned one, or
its apartment in one.

In the savage state every family owns a shelter as good as the best,
and sufficient for its coarser and simpler wants; but I think that I
speak within bounds when I say that, though the birds of the air have
their nests, and the foxes their holes, and the savages their wigwams,
in modern civilized society not more than one half the families own a
shelter. In the large towns and cities, where civilization especially
prevails, the number of those who own a shelter is a very small
fraction of the whole. The rest pay an annual tax for this outside
garment of all, become indispensable summer and winter, which would buy
a village of Indian wigwams, but now helps to keep them poor as long as
they live. I do not mean to insist here on the disadvantage of hiring
compared with owning, but it is evident that the savage owns his
shelter because it costs so little, while the civilized man hires his
commonly because he cannot afford to own it; nor can he, in the long
run, any better afford to hire. But, answers one, by merely paying this
tax the poor civilized man secures an abode which is a palace compared
with the savage’s. An annual rent of from twenty-five to a hundred
dollars, these are the country rates, entitles him to the benefit of
the improvements of centuries, spacious apartments, clean paint and
paper, Rumford fireplace, back plastering, Venetian blinds, copper
pump, spring lock, a commodious cellar, and many other things. But how
happens it that he who is said to enjoy these things is so commonly a
_poor_ civilized man, while the savage, who has them not, is rich as a
savage? If it is asserted that civilization is a real advance in the
condition of man,—and I think that it is, though only the wise improve
their advantages,—it must be shown that it has produced better
dwellings without making them more costly; and the cost of a thing is
the amount of what I will call life which is required to be exchanged
for it, immediately or in the long run. An average house in this
neighborhood costs perhaps eight hundred dollars, and to lay up this
sum will take from ten to fifteen years of the laborer’s life, even if
he is not encumbered with a family;—estimating the pecuniary value of
every man’s labor at one dollar a day, for if some receive more, others
receive less;—so that he must have spent more than half his life
commonly before _his_ wigwam will be earned. If we suppose him to pay a
rent instead, this is but a doubtful choice of evils. Would the savage
have been wise to exchange his wigwam for a palace on these terms?

It may be guessed that I reduce almost the whole advantage of holding
this superfluous property as a fund in store against the future, so far
as the individual is concerned, mainly to the defraying of funeral
expenses. But perhaps a man is not required to bury himself.
Nevertheless this points to an important distinction between the
civilized man and the savage; and, no doubt, they have designs on us
for our benefit, in making the life of a civilized people an
_institution_, in which the life of the individual is to a great extent
absorbed, in order to preserve and perfect that of the race. But I wish
to show at what a sacrifice this advantage is at present obtained, and
to suggest that we may possibly so live as to secure all the advantage
without suffering any of the disadvantage. What mean ye by saying that
the poor ye have always with you, or that the fathers have eaten sour
grapes, and the children’s teeth are set on edge?

“As I live, saith the Lord God, ye shall not have occasion any more to
use this proverb in Israel.”

“Behold all souls are mine; as the soul of the father, so also the soul
of the son is mine: the soul that sinneth, it shall die.”

When I consider my neighbors, the farmers of Concord, who are at least
as well off as the other classes, I find that for the most part they
have been toiling twenty, thirty, or forty years, that they may become
the real owners of their farms, which commonly they have inherited with
encumbrances, or else bought with hired money,—and we may regard one
third of that toil as the cost of their houses,—but commonly they have
not paid for them yet. It is true, the encumbrances sometimes outweigh
the value of the farm, so that the farm itself becomes one great
encumbrance, and still a man is found to inherit it, being well
acquainted with it, as he says. On applying to the assessors, I am
surprised to learn that they cannot at once name a dozen in the town
who own their farms free and clear. If you would know the history of
these homesteads, inquire at the bank where they are mortgaged. The man
who has actually paid for his farm with labor on it is so rare that
every neighbor can point to him. I doubt if there are three such men in
Concord. What has been said of the merchants, that a very large
majority, even ninety-seven in a hundred, are sure to fail, is equally
true of the farmers. With regard to the merchants, however, one of them
says pertinently that a great part of their failures are not genuine
pecuniary failures, but merely failures to fulfil their engagements,
because it is inconvenient; that is, it is the moral character that
breaks down. But this puts an infinitely worse face on the matter, and
suggests, beside, that probably not even the other three succeed in
saving their souls, but are perchance bankrupt in a worse sense than
they who fail honestly. Bankruptcy and repudiation are the springboards
from which much of our civilization vaults and turns its somersets, but
the savage stands on the unelastic plank of famine. Yet the Middlesex
Cattle Show goes off here with _éclat_ annually, as if all the joints
of the agricultural machine were suent.

The farmer is endeavoring to solve the problem of a livelihood by a
formula more complicated than the problem itself. To get his
shoestrings he speculates in herds of cattle. With consummate skill he
has set his trap with a hair spring to catch comfort and independence,
and then, as he turned away, got his own leg into it. This is the
reason he is poor; and for a similar reason we are all poor in respect
to a thousand savage comforts, though surrounded by luxuries. As
Chapman sings,—

     “The false society of men—
             —for earthly greatness
     All heavenly comforts rarefies to air.”

And when the farmer has got his house, he may not be the richer but the
poorer for it, and it be the house that has got him. As I understand
it, that was a valid objection urged by Momus against the house which
Minerva made, that she “had not made it movable, by which means a bad
neighborhood might be avoided;” and it may still be urged, for our
houses are such unwieldy property that we are often imprisoned rather
than housed in them; and the bad neighborhood to be avoided is our own
scurvy selves. I know one or two families, at least, in this town, who,
for nearly a generation, have been wishing to sell their houses in the
outskirts and move into the village, but have not been able to
accomplish it, and only death will set them free.

Granted that the _majority_ are able at last either to own or hire the
modern house with all its improvements. While civilization has been
improving our houses, it has not equally improved the men who are to
inhabit them. It has created palaces, but it was not so easy to create
noblemen and kings. And _if the civilized man’s pursuits are no
worthier than the savage’s, if he is employed the greater part of his
life in obtaining gross necessaries and comforts merely, why should he
have a better dwelling than the former?_

But how do the poor minority fare? Perhaps it will be found, that just
in proportion as some have been placed in outward circumstances above
the savage, others have been degraded below him. The luxury of one
class is counterbalanced by the indigence of another. On the one side
is the palace, on the other are the almshouse and “silent poor.” The
myriads who built the pyramids to be the tombs of the Pharaohs were fed
on garlic, and it may be were not decently buried themselves. The mason
who finishes the cornice of the palace returns at night perchance to a
hut not so good as a wigwam. It is a mistake to suppose that, in a
country where the usual evidences of civilization exist, the condition
of a very large body of the inhabitants may not be as degraded as that
of savages. I refer to the degraded poor, not now to the degraded rich.
To know this I should not need to look farther than to the shanties
which every where border our railroads, that last improvement in
civilization; where I see in my daily walks human beings living in
sties, and all winter with an open door, for the sake of light, without
any visible, often imaginable, wood pile, and the forms of both old and
young are permanently contracted by the long habit of shrinking from
cold and misery, and the development of all their limbs and faculties
is checked. It certainly is fair to look at that class by whose labor
the works which distinguish this generation are accomplished. Such too,
to a greater or less extent, is the condition of the operatives of
every denomination in England, which is the great workhouse of the
world. Or I could refer you to Ireland, which is marked as one of the
white or enlightened spots on the map. Contrast the physical condition
of the Irish with that of the North American Indian, or the South Sea
Islander, or any other savage race before it was degraded by contact
with the civilized man. Yet I have no doubt that that people’s rulers
are as wise as the average of civilized rulers. Their condition only
proves what squalidness may consist with civilization. I hardly need
refer now to the laborers in our Southern States who produce the staple
exports of this country, and are themselves a staple production of the
South. But to confine myself to those who are said to be in _moderate_
circumstances.

Most men appear never to have considered what a house is, and are
actually though needlessly poor all their lives because they think that
they must have such a one as their neighbors have. As if one were to
wear any sort of coat which the tailor might cut out for him, or,
gradually leaving off palmleaf hat or cap of woodchuck skin, complain
of hard times because he could not afford to buy him a crown! It is
possible to invent a house still more convenient and luxurious than we
have, which yet all would admit that man could not afford to pay for.
Shall we always study to obtain more of these things, and not sometimes
to be content with less? Shall the respectable citizen thus gravely
teach, by precept and example, the necessity of the young man’s
providing a certain number of superfluous glow-shoes, and umbrellas,
and empty guest chambers for empty guests, before he dies? Why should
not our furniture be as simple as the Arab’s or the Indian’s? When I
think of the benefactors of the race, whom we have apotheosized as
messengers from heaven, bearers of divine gifts to man, I do not see in
my mind any retinue at their heels, any car-load of fashionable
furniture. Or what if I were to allow—would it not be a singular
allowance?—that our furniture should be more complex than the Arab’s,
in proportion as we are morally and intellectually his superiors! At
present our houses are cluttered and defiled with it, and a good
housewife would sweep out the greater part into the dust hole, and not
leave her morning’s work undone. Morning work! By the blushes of Aurora
and the music of Memnon, what should be man’s _morning work_ in this
world? I had three pieces of limestone on my desk, but I was terrified
to find that they required to be dusted daily, when the furniture of my
mind was all undusted still, and I threw them out the window in
disgust. How, then, could I have a furnished house? I would rather sit
in the open air, for no dust gathers on the grass, unless where man has
broken ground.

It is the luxurious and dissipated who set the fashions which the herd
so diligently follow. The traveller who stops at the best houses, so
called, soon discovers this, for the publicans presume him to be a
Sardanapalus, and if he resigned himself to their tender mercies he
would soon be completely emasculated. I think that in the railroad car
we are inclined to spend more on luxury than on safety and convenience,
and it threatens without attaining these to become no better than a
modern drawing room, with its divans, and ottomans, and sun-shades, and
a hundred other oriental things, which we are taking west with us,
invented for the ladies of the harem and the effeminate natives of the
Celestial Empire, which Jonathan should be ashamed to know the names
of. I would rather sit on a pumpkin and have it all to myself than be
crowded on a velvet cushion. I would rather ride on earth in an ox cart
with a free circulation, than go to heaven in the fancy car of an
excursion train and breathe a _malaria_ all the way.

The very simplicity and nakedness of man’s life in the primitive ages
imply this advantage at least, that they left him still but a sojourner
in nature. When he was refreshed with food and sleep he contemplated
his journey again. He dwelt, as it were, in a tent in this world, and
was either threading the valleys, or crossing the plains, or climbing
the mountain tops. But lo! men have become the tools of their tools.
The man who independently plucked the fruits when he was hungry is
become a farmer; and he who stood under a tree for shelter, a
housekeeper. We now no longer camp as for a night, but have settled
down on earth and forgotten heaven. We have adopted Christianity merely
as an improved method of _agri_-culture. We have built for this world a
family mansion, and for the next a family tomb. The best works of art
are the expression of man’s struggle to free himself from this
condition, but the effect of our art is merely to make this low state
comfortable and that higher state to be forgotten. There is actually no
place in this village for a work of _fine_ art, if any had come down to
us, to stand, for our lives, our houses and streets, furnish no proper
pedestal for it. There is not a nail to hang a picture on, nor a shelf
to receive the bust of a hero or a saint. When I consider how our
houses are built and paid for, or not paid for, and their internal
economy managed and sustained, I wonder that the floor does not give
way under the visitor while he is admiring the gewgaws upon the
mantel-piece, and let him through into the cellar, to some solid and
honest though earthy foundation. I cannot but perceive that this so
called rich and refined life is a thing jumped at, and I do not get on
in the enjoyment of the _fine_ arts which adorn it, my attention being
wholly occupied with the jump; for I remember that the greatest genuine
leap, due to human muscles alone, on record, is that of certain
wandering Arabs, who are said to have cleared twenty-five feet on level
ground. Without factitious support, man is sure to come to earth again
beyond that distance. The first question which I am tempted to put to
the proprietor of such great impropriety is, Who bolsters you? Are you
one of the ninety-seven who fail, or of the three who succeed? Answer
me these questions, and then perhaps I may look at your bawbles and
find them ornamental. The cart before the horse is neither beautiful
nor useful. Before we can adorn our houses with beautiful objects the
walls must be stripped, and our lives must be stripped, and beautiful
housekeeping and beautiful living be laid for a foundation: now, a
taste for the beautiful is most cultivated out of doors, where there is
no house and no housekeeper.

Old Johnson, in his “Wonder-Working Providence,” speaking of the first
settlers of this town, with whom he was contemporary, tells us that
“they burrow themselves in the earth for their first shelter under some
hillside, and, casting the soil aloft upon timber, they make a smoky
fire against the earth, at the highest side.” They did not “provide
them houses,” says he, “till the earth, by the Lord’s blessing, brought
forth bread to feed them,” and the first year’s crop was so light that
“they were forced to cut their bread very thin for a long season.” The
secretary of the Province of New Netherland, writing in Dutch, in 1650,
for the information of those who wished to take up land there, states
more particularly that “those in New Netherland, and especially in New
England, who have no means to build farmhouses at first according to
their wishes, dig a square pit in the ground, cellar fashion, six or
seven feet deep, as long and as broad as they think proper, case the
earth inside with wood all round the wall, and line the wood with the
bark of trees or something else to prevent the caving in of the earth;
floor this cellar with plank, and wainscot it overhead for a ceiling,
raise a roof of spars clear up, and cover the spars with bark or green
sods, so that they can live dry and warm in these houses with their
entire families for two, three, and four years, it being understood
that partitions are run through those cellars which are adapted to the
size of the family. The wealthy and principal men in New England, in
the beginning of the colonies, commenced their first dwelling houses in
this fashion for two reasons; firstly, in order not to waste time in
building, and not to want food the next season; secondly, in order not
to discourage poor laboring people whom they brought over in numbers
from Fatherland. In the course of three or four years, when the country
became adapted to agriculture, they built themselves handsome houses,
spending on them several thousands.”

In this course which our ancestors took there was a show of prudence at
least, as if their principle were to satisfy the more pressing wants
first. But are the more pressing wants satisfied now? When I think of
acquiring for myself one of our luxurious dwellings, I am deterred,
for, so to speak, the country is not yet adapted to _human_ culture,
and we are still forced to cut our _spiritual_ bread far thinner than
our forefathers did their wheaten. Not that all architectural ornament
is to be neglected even in the rudest periods; but let our houses first
be lined with beauty, where they come in contact with our lives, like
the tenement of the shellfish, and not overlaid with it. But, alas! I
have been inside one or two of them, and know what they are lined with.

Though we are not so degenerate but that we might possibly live in a
cave or a wigwam or wear skins today, it certainly is better to accept
the advantages, though so dearly bought, which the invention and
industry of mankind offer. In such a neighborhood as this, boards and
shingles, lime and bricks, are cheaper and more easily obtained than
suitable caves, or whole logs, or bark in sufficient quantities, or
even well-tempered clay or flat stones. I speak understandingly on this
subject, for I have made myself acquainted with it both theoretically
and practically. With a little more wit we might use these materials so
as to become richer than the richest now are, and make our civilization
a blessing. The civilized man is a more experienced and wiser savage.
But to make haste to my own experiment.



Near the end of March, 1845, I borrowed an axe and went down to the
woods by Walden Pond, nearest to where I intended to build my house,
and began to cut down some tall, arrowy white pines, still in their
youth, for timber. It is difficult to begin without borrowing, but
perhaps it is the most generous course thus to permit your fellow-men
to have an interest in your enterprise. The owner of the axe, as he
released his hold on it, said that it was the apple of his eye; but I
returned it sharper than I received it. It was a pleasant hillside
where I worked, covered with pine woods, through which I looked out on
the pond, and a small open field in the woods where pines and hickories
were springing up. The ice in the pond was not yet dissolved, though
there were some open spaces, and it was all dark colored and saturated
with water. There were some slight flurries of snow during the days
that I worked there; but for the most part when I came out on to the
railroad, on my way home, its yellow sand heap stretched away gleaming
in the hazy atmosphere, and the rails shone in the spring sun, and I
heard the lark and pewee and other birds already come to commence
another year with us. They were pleasant spring days, in which the
winter of man’s discontent was thawing as well as the earth, and the
life that had lain torpid began to stretch itself. One day, when my axe
had come off and I had cut a green hickory for a wedge, driving it with
a stone, and had placed the whole to soak in a pond hole in order to
swell the wood, I saw a striped snake run into the water, and he lay on
the bottom, apparently without inconvenience, as long as I stayed
there, or more than a quarter of an hour; perhaps because he had not
yet fairly come out of the torpid state. It appeared to me that for a
like reason men remain in their present low and primitive condition;
but if they should feel the influence of the spring of springs arousing
them, they would of necessity rise to a higher and more ethereal life.
I had previously seen the snakes in frosty mornings in my path with
portions of their bodies still numb and inflexible, waiting for the sun
to thaw them. On the 1st of April it rained and melted the ice, and in
the early part of the day, which was very foggy, I heard a stray goose
groping about over the pond and cackling as if lost, or like the spirit
of the fog.

So I went on for some days cutting and hewing timber, and also studs
and rafters, all with my narrow axe, not having many communicable or
scholar-like thoughts, singing to myself,—

     Men say they know many things;
     But lo! they have taken wings,—
     The arts and sciences,
     And a thousand appliances;
     The wind that blows
     Is all that any body knows.

I hewed the main timbers six inches square, most of the studs on two
sides only, and the rafters and floor timbers on one side, leaving the
rest of the bark on, so that they were just as straight and much
stronger than sawed ones. Each stick was carefully mortised or tenoned
by its stump, for I had borrowed other tools by this time. My days in
the woods were not very long ones; yet I usually carried my dinner of
bread and butter, and read the newspaper in which it was wrapped, at
noon, sitting amid the green pine boughs which I had cut off, and to my
bread was imparted some of their fragrance, for my hands were covered
with a thick coat of pitch. Before I had done I was more the friend
than the foe of the pine tree, though I had cut down some of them,
having become better acquainted with it. Sometimes a rambler in the
wood was attracted by the sound of my axe, and we chatted pleasantly
over the chips which I had made.

By the middle of April, for I made no haste in my work, but rather made
the most of it, my house was framed and ready for the raising. I had
already bought the shanty of James Collins, an Irishman who worked on
the Fitchburg Railroad, for boards. James Collins’ shanty was
considered an uncommonly fine one. When I called to see it he was not
at home. I walked about the outside, at first unobserved from within,
the window was so deep and high. It was of small dimensions, with a
peaked cottage roof, and not much else to be seen, the dirt being
raised five feet all around as if it were a compost heap. The roof was
the soundest part, though a good deal warped and made brittle by the
sun. Door-sill there was none, but a perennial passage for the hens
under the door board. Mrs. C. came to the door and asked me to view it
from the inside. The hens were driven in by my approach. It was dark,
and had a dirt floor for the most part, dank, clammy, and aguish, only
here a board and there a board which would not bear removal. She
lighted a lamp to show me the inside of the roof and the walls, and
also that the board floor extended under the bed, warning me not to
step into the cellar, a sort of dust hole two feet deep. In her own
words, they were “good boards overhead, good boards all around, and a
good window,”—of two whole squares originally, only the cat had passed
out that way lately. There was a stove, a bed, and a place to sit, an
infant in the house where it was born, a silk parasol, gilt-framed
looking-glass, and a patent new coffee mill nailed to an oak sapling,
all told. The bargain was soon concluded, for James had in the
meanwhile returned. I to pay four dollars and twenty-five cents
to-night, he to vacate at five to-morrow morning, selling to nobody
else meanwhile: I to take possession at six. It were well, he said, to
be there early, and anticipate certain indistinct but wholly unjust
claims on the score of ground rent and fuel. This he assured me was the
only encumbrance. At six I passed him and his family on the road. One
large bundle held their all,—bed, coffee-mill, looking-glass, hens,—all
but the cat, she took to the woods and became a wild cat, and, as I
learned afterward, trod in a trap set for woodchucks, and so became a
dead cat at last.

I took down this dwelling the same morning, drawing the nails, and
removed it to the pond side by small cartloads, spreading the boards on
the grass there to bleach and warp back again in the sun. One early
thrush gave me a note or two as I drove along the woodland path. I was
informed treacherously by a young Patrick that neighbor Seeley, an
Irishman, in the intervals of the carting, transferred the still
tolerable, straight, and drivable nails, staples, and spikes to his
pocket, and then stood when I came back to pass the time of day, and
look freshly up, unconcerned, with spring thoughts, at the devastation;
there being a dearth of work, as he said. He was there to represent
spectatordom, and help make this seemingly insignificant event one with
the removal of the gods of Troy.

I dug my cellar in the side of a hill sloping to the south, where a
woodchuck had formerly dug his burrow, down through sumach and
blackberry roots, and the lowest stain of vegetation, six feet square
by seven deep, to a fine sand where potatoes would not freeze in any
winter. The sides were left shelving, and not stoned; but the sun
having never shone on them, the sand still keeps its place. It was but
two hours’ work. I took particular pleasure in this breaking of ground,
for in almost all latitudes men dig into the earth for an equable
temperature. Under the most splendid house in the city is still to be
found the cellar where they store their roots as of old, and long after
the superstructure has disappeared posterity remark its dent in the
earth. The house is still but a sort of porch at the entrance of a
burrow.

At length, in the beginning of May, with the help of some of my
acquaintances, rather to improve so good an occasion for neighborliness
than from any necessity, I set up the frame of my house. No man was
ever more honored in the character of his raisers than I. They are
destined, I trust, to assist at the raising of loftier structures one
day. I began to occupy my house on the 4th of July, as soon as it was
boarded and roofed, for the boards were carefully feather-edged and
lapped, so that it was perfectly impervious to rain; but before
boarding I laid the foundation of a chimney at one end, bringing two
cartloads of stones up the hill from the pond in my arms. I built the
chimney after my hoeing in the fall, before a fire became necessary for
warmth, doing my cooking in the mean while out of doors on the ground,
early in the morning: which mode I still think is in some respects more
convenient and agreeable than the usual one. When it stormed before my
bread was baked, I fixed a few boards over the fire, and sat under them
to watch my loaf, and passed some pleasant hours in that way. In those
days, when my hands were much employed, I read but little, but the
least scraps of paper which lay on the ground, my holder, or
tablecloth, afforded me as much entertainment, in fact answered the
same purpose as the Iliad.



It would be worth the while to build still more deliberately than I
did, considering, for instance, what foundation a door, a window, a
cellar, a garret, have in the nature of man, and perchance never
raising any superstructure until we found a better reason for it than
our temporal necessities even. There is some of the same fitness in a
man’s building his own house that there is in a bird’s building its own
nest. Who knows but if men constructed their dwellings with their own
hands, and provided food for themselves and families simply and
honestly enough, the poetic faculty would be universally developed, as
birds universally sing when they are so engaged? But alas! we do like
cowbirds and cuckoos, which lay their eggs in nests which other birds
have built, and cheer no traveller with their chattering and unmusical
notes. Shall we forever resign the pleasure of construction to the
carpenter? What does architecture amount to in the experience of the
mass of men? I never in all my walks came across a man engaged in so
simple and natural an occupation as building his house. We belong to
the community. It is not the tailor alone who is the ninth part of a
man; it is as much the preacher, and the merchant, and the farmer.
Where is this division of labor to end? and what object does it finally
serve? No doubt another _may_ also think for me; but it is not
therefore desirable that he should do so to the exclusion of my
thinking for myself.

True, there are architects so called in this country, and I have heard
of one at least possessed with the idea of making architectural
ornaments have a core of truth, a necessity, and hence a beauty, as if
it were a revelation to him. All very well perhaps from his point of
view, but only a little better than the common dilettantism. A
sentimental reformer in architecture, he began at the cornice, not at
the foundation. It was only how to put a core of truth within the
ornaments, that every sugar plum in fact might have an almond or
caraway seed in it,—though I hold that almonds are most wholesome
without the sugar,—and not how the inhabitant, the indweller, might
build truly within and without, and let the ornaments take care of
themselves. What reasonable man ever supposed that ornaments were
something outward and in the skin merely,—that the tortoise got his
spotted shell, or the shellfish its mother-o’-pearl tints, by such a
contract as the inhabitants of Broadway their Trinity Church? But a man
has no more to do with the style of architecture of his house than a
tortoise with that of its shell: nor need the soldier be so idle as to
try to paint the precise color of his virtue on his standard. The enemy
will find it out. He may turn pale when the trial comes. This man
seemed to me to lean over the cornice, and timidly whisper his half
truth to the rude occupants who really knew it better than he. What of
architectural beauty I now see, I know has gradually grown from within
outward, out of the necessities and character of the indweller, who is
the only builder,—out of some unconscious truthfulness, and nobleness,
without ever a thought for the appearance and whatever additional
beauty of this kind is destined to be produced will be preceded by a
like unconscious beauty of life. The most interesting dwellings in this
country, as the painter knows, are the most unpretending, humble log
huts and cottages of the poor commonly; it is the life of the
inhabitants whose shells they are, and not any peculiarity in their
surfaces merely, which makes them _picturesque;_ and equally
interesting will be the citizen’s suburban box, when his life shall be
as simple and as agreeable to the imagination, and there is as little
straining after effect in the style of his dwelling. A great proportion
of architectural ornaments are literally hollow, and a September gale
would strip them off, like borrowed plumes, without injury to the
substantials. They can do without _architecture_ who have no olives nor
wines in the cellar. What if an equal ado were made about the ornaments
of style in literature, and the architects of our bibles spent as much
time about their cornices as the architects of our churches do? So are
made the _belles-lettres_ and the _beaux-arts_ and their professors.
Much it concerns a man, forsooth, how a few sticks are slanted over him
or under him, and what colors are daubed upon his box. It would signify
somewhat, if, in any earnest sense, _he_ slanted them and daubed it;
but the spirit having departed out of the tenant, it is of a piece with
constructing his own coffin,—the architecture of the grave, and
“carpenter” is but another name for “coffin-maker.” One man says, in
his despair or indifference to life, take up a handful of the earth at
your feet, and paint your house that color. Is he thinking of his last
and narrow house? Toss up a copper for it as well. What an abundance of
leisure he must have! Why do you take up a handful of dirt? Better
paint your house your own complexion; let it turn pale or blush for
you. An enterprise to improve the style of cottage architecture! When
you have got my ornaments ready I will wear them.

Before winter I built a chimney, and shingled the sides of my house,
which were already impervious to rain, with imperfect and sappy
shingles made of the first slice of the log, whose edges I was obliged
to straighten with a plane.

I have thus a tight shingled and plastered house, ten feet wide by
fifteen long, and eight-feet posts, with a garret and a closet, a large
window on each side, two trap doors, one door at the end, and a brick
fireplace opposite. The exact cost of my house, paying the usual price
for such materials as I used, but not counting the work, all of which
was done by myself, was as follows; and I give the details because very
few are able to tell exactly what their houses cost, and fewer still,
if any, the separate cost of the various materials which compose them:—


    Boards.......................... $ 8.03½, mostly shanty boards.
    Refuse shingles for roof sides,..  4.00
    Laths,...........................  1.25
    Two second-hand windows
       with glass,...................  2.43
    One thousand old brick,..........  4.00
    Two casks of lime,...............  2.40  That was high.
    Hair,............................  0.31  More than I needed.
    Mantle-tree iron,................  0.15
    Nails,...........................  3.90
    Hinges and screws,...............  0.14
    Latch,...........................  0.10
    Chalk,...........................  0.01
    Transportation,..................  1.40  I carried a good part
                                     ———— on my back.
        In all,..................... $28.12½


These are all the materials excepting the timber stones and sand, which
I claimed by squatter’s right. I have also a small wood-shed adjoining,
made chiefly of the stuff which was left after building the house.

I intend to build me a house which will surpass any on the main street
in Concord in grandeur and luxury, as soon as it pleases me as much and
will cost me no more than my present one.

I thus found that the student who wishes for a shelter can obtain one
for a lifetime at an expense not greater than the rent which he now
pays annually. If I seem to boast more than is becoming, my excuse is
that I brag for humanity rather than for myself; and my shortcomings
and inconsistencies do not affect the truth of my statement.
Notwithstanding much cant and hypocrisy,—chaff which I find it
difficult to separate from my wheat, but for which I am as sorry as any
man,—I will breathe freely and stretch myself in this respect, it is
such a relief to both the moral and physical system; and I am resolved
that I will not through humility become the devil’s attorney. I will
endeavor to speak a good word for the truth. At Cambridge College the
mere rent of a student’s room, which is only a little larger than my
own, is thirty dollars each year, though the corporation had the
advantage of building thirty-two side by side and under one roof, and
the occupant suffers the inconvenience of many and noisy neighbors, and
perhaps a residence in the fourth story. I cannot but think that if we
had more true wisdom in these respects, not only less education would
be needed, because, forsooth, more would already have been acquired,
but the pecuniary expense of getting an education would in a great
measure vanish. Those conveniences which the student requires at
Cambridge or elsewhere cost him or somebody else ten times as great a
sacrifice of life as they would with proper management on both sides.
Those things for which the most money is demanded are never the things
which the student most wants. Tuition, for instance, is an important
item in the term bill, while for the far more valuable education which
he gets by associating with the most cultivated of his contemporaries
no charge is made. The mode of founding a college is, commonly, to get
up a subscription of dollars and cents, and then following blindly the
principles of a division of labor to its extreme, a principle which
should never be followed but with circumspection,—to call in a
contractor who makes this a subject of speculation, and he employs
Irishmen or other operatives actually to lay the foundations, while the
students that are to be are said to be fitting themselves for it; and
for these oversights successive generations have to pay. I think that
it would be _better than this_, for the students, or those who desire
to be benefited by it, even to lay the foundation themselves. The
student who secures his coveted leisure and retirement by
systematically shirking any labor necessary to man obtains but an
ignoble and unprofitable leisure, defrauding himself of the experience
which alone can make leisure fruitful. “But,” says one, “you do not
mean that the students should go to work with their hands instead of
their heads?” I do not mean that exactly, but I mean something which he
might think a good deal like that; I mean that they should not _play_
life, or _study_ it merely, while the community supports them at this
expensive game, but earnestly _live_ it from beginning to end. How
could youths better learn to live than by at once trying the experiment
of living? Methinks this would exercise their minds as much as
mathematics. If I wished a boy to know something about the arts and
sciences, for instance, I would not pursue the common course, which is
merely to send him into the neighborhood of some professor, where any
thing is professed and practised but the art of life;—to survey the
world through a telescope or a microscope, and never with his natural
eye; to study chemistry, and not learn how his bread is made, or
mechanics, and not learn how it is earned; to discover new satellites
to Neptune, and not detect the motes in his eyes, or to what vagabond
he is a satellite himself; or to be devoured by the monsters that swarm
all around him, while contemplating the monsters in a drop of vinegar.
Which would have advanced the most at the end of a month,—the boy who
had made his own jackknife from the ore which he had dug and smelted,
reading as much as would be necessary for this,—or the boy who had
attended the lectures on metallurgy at the Institute in the mean while,
and had received a Rodgers’ penknife from his father? Which would be
most likely to cut his fingers?... To my astonishment I was informed on
leaving college that I had studied navigation!—why, if I had taken one
turn down the harbor I should have known more about it. Even the _poor_
student studies and is taught only _political_ economy, while that
economy of living which is synonymous with philosophy is not even
sincerely professed in our colleges. The consequence is, that while he
is reading Adam Smith, Ricardo, and Say, he runs his father in debt
irretrievably.

As with our colleges, so with a hundred “modern improvements”; there is
an illusion about them; there is not always a positive advance. The
devil goes on exacting compound interest to the last for his early
share and numerous succeeding investments in them. Our inventions are
wont to be pretty toys, which distract our attention from serious
things. They are but improved means to an unimproved end, an end which
it was already but too easy to arrive at; as railroads lead to Boston
or New York. We are in great haste to construct a magnetic telegraph
from Maine to Texas; but Maine and Texas, it may be, have nothing
important to communicate. Either is in such a predicament as the man
who was earnest to be introduced to a distinguished deaf woman, but
when he was presented, and one end of her ear trumpet was put into his
hand, had nothing to say. As if the main object were to talk fast and
not to talk sensibly. We are eager to tunnel under the Atlantic and
bring the old world some weeks nearer to the new; but perchance the
first news that will leak through into the broad, flapping American ear
will be that the Princess Adelaide has the whooping cough. After all,
the man whose horse trots a mile in a minute does not carry the most
important messages; he is not an evangelist, nor does he come round
eating locusts and wild honey. I doubt if Flying Childers ever carried
a peck of corn to mill.

One says to me, “I wonder that you do not lay up money; you love to
travel; you might take the cars and go to Fitchburg to-day and see the
country.” But I am wiser than that. I have learned that the swiftest
traveller is he that goes afoot. I say to my friend, Suppose we try who
will get there first. The distance is thirty miles; the fare ninety
cents. That is almost a day’s wages. I remember when wages were sixty
cents a day for laborers on this very road. Well, I start now on foot,
and get there before night; I have travelled at that rate by the week
together. You will in the mean while have earned your fare, and arrive
there some time to-morrow, or possibly this evening, if you are lucky
enough to get a job in season. Instead of going to Fitchburg, you will
be working here the greater part of the day. And so, if the railroad
reached round the world, I think that I should keep ahead of you; and
as for seeing the country and getting experience of that kind, I should
have to cut your acquaintance altogether.

Such is the universal law, which no man can ever outwit, and with
regard to the railroad even we may say it is as broad as it is long. To
make a railroad round the world available to all mankind is equivalent
to grading the whole surface of the planet. Men have an indistinct
notion that if they keep up this activity of joint stocks and spades
long enough all will at length ride somewhere, in next to no time, and
for nothing; but though a crowd rushes to the depot, and the conductor
shouts “All aboard!” when the smoke is blown away and the vapor
condensed, it will be perceived that a few are riding, but the rest are
run over,—and it will be called, and will be, “A melancholy accident.”
No doubt they can ride at last who shall have earned their fare, that
is, if they survive so long, but they will probably have lost their
elasticity and desire to travel by that time. This spending of the best
part of one’s life earning money in order to enjoy a questionable
liberty during the least valuable part of it, reminds me of the
Englishman who went to India to make a fortune first, in order that he
might return to England and live the life of a poet. He should have
gone up garret at once. “What!” exclaim a million Irishmen starting up
from all the shanties in the land, “is not this railroad which we have
built a good thing?” Yes, I answer, _comparatively_ good, that is, you
might have done worse; but I wish, as you are brothers of mine, that
you could have spent your time better than digging in this dirt.



Before I finished my house, wishing to earn ten or twelve dollars by
some honest and agreeable method, in order to meet my unusual expenses,
I planted about two acres and a half of light and sandy soil near it
chiefly with beans, but also a small part with potatoes, corn, peas,
and turnips. The whole lot contains eleven acres, mostly growing up to
pines and hickories, and was sold the preceding season for eight
dollars and eight cents an acre. One farmer said that it was “good for
nothing but to raise cheeping squirrels on.” I put no manure whatever
on this land, not being the owner, but merely a squatter, and not
expecting to cultivate so much again, and I did not quite hoe it all
once. I got out several cords of stumps in ploughing, which supplied me
with fuel for a long time, and left small circles of virgin mould,
easily distinguishable through the summer by the greater luxuriance of
the beans there. The dead and for the most part unmerchantable wood
behind my house, and the driftwood from the pond, have supplied the
remainder of my fuel. I was obliged to hire a team and a man for the
ploughing, though I held the plough myself. My farm outgoes for the
first season were, for implements, seed, work, &c., $14.72½. The seed
corn was given me. This never costs anything to speak of, unless you
plant more than enough. I got twelve bushels of beans, and eighteen
bushels of potatoes, beside some peas and sweet corn. The yellow corn
and turnips were too late to come to any thing. My whole income from
the farm was

                                       $ 23.44
      Deducting the outgoes,...........  14.72½
                                         ————
      There are left,................. $  8.71½,

beside produce consumed and on hand at the time this estimate was made
of the value of $4.50,—the amount on hand much more than balancing a
little grass which I did not raise. All things considered, that is,
considering the importance of a man’s soul and of to-day,
notwithstanding the short time occupied by my experiment, nay, partly
even because of its transient character, I believe that that was doing
better than any farmer in Concord did that year.

The next year I did better still, for I spaded up all the land which I
required, about a third of an acre, and I learned from the experience
of both years, not being in the least awed by many celebrated works on
husbandry, Arthur Young among the rest, that if one would live simply
and eat only the crop which he raised, and raise no more than he ate,
and not exchange it for an insufficient quantity of more luxurious and
expensive things, he would need to cultivate only a few rods of ground,
and that it would be cheaper to spade up that than to use oxen to
plough it, and to select a fresh spot from time to time than to manure
the old, and he could do all his necessary farm work as it were with
his left hand at odd hours in the summer; and thus he would not be tied
to an ox, or horse, or cow, or pig, as at present. I desire to speak
impartially on this point, and as one not interested in the success or
failure of the present economical and social arrangements. I was more
independent than any farmer in Concord, for I was not anchored to a
house or farm, but could follow the bent of my genius, which is a very
crooked one, every moment. Beside being better off than they already,
if my house had been burned or my crops had failed, I should have been
nearly as well off as before.

I am wont to think that men are not so much the keepers of herds as
herds are the keepers of men, the former are so much the freer. Men and
oxen exchange work; but if we consider necessary work only, the oxen
will be seen to have greatly the advantage, their farm is so much the
larger. Man does some of his part of the exchange work in his six weeks
of haying, and it is no boy’s play. Certainly no nation that lived
simply in all respects, that is, no nation of philosophers, would
commit so great a blunder as to use the labor of animals. True, there
never was and is not likely soon to be a nation of philosophers, nor am
I certain it is desirable that there should be. However, _I_ should
never have broken a horse or bull and taken him to board for any work
he might do for me, for fear I should become a horse-man or a herds-man
merely; and if society seems to be the gainer by so doing, are we
certain that what is one man’s gain is not another’s loss, and that the
stable-boy has equal cause with his master to be satisfied? Granted
that some public works would not have been constructed without this
aid, and let man share the glory of such with the ox and horse; does it
follow that he could not have accomplished works yet more worthy of
himself in that case? When men begin to do, not merely unnecessary or
artistic, but luxurious and idle work, with their assistance, it is
inevitable that a few do all the exchange work with the oxen, or, in
other words, become the slaves of the strongest. Man thus not only
works for the animal within him, but, for a symbol of this, he works
for the animal without him. Though we have many substantial houses of
brick or stone, the prosperity of the farmer is still measured by the
degree to which the barn overshadows the house. This town is said to
have the largest houses for oxen, cows, and horses hereabouts, and it
is not behindhand in its public buildings; but there are very few halls
for free worship or free speech in this county. It should not be by
their architecture, but why not even by their power of abstract
thought, that nations should seek to commemorate themselves? How much
more admirable the Bhagvat-Geeta than all the ruins of the East! Towers
and temples are the luxury of princes. A simple and independent mind
does not toil at the bidding of any prince. Genius is not a retainer to
any emperor, nor is its material silver, or gold, or marble, except to
a trifling extent. To what end, pray, is so much stone hammered? In
Arcadia, when I was there, I did not see any hammering stone. Nations
are possessed with an insane ambition to perpetuate the memory of
themselves by the amount of hammered stone they leave. What if equal
pains were taken to smooth and polish their manners? One piece of good
sense would be more memorable than a monument as high as the moon. I
love better to see stones in place. The grandeur of Thebes was a vulgar
grandeur. More sensible is a rod of stone wall that bounds an honest
man’s field than a hundred-gated Thebes that has wandered farther from
the true end of life. The religion and civilization which are barbaric
and heathenish build splendid temples; but what you might call
Christianity does not. Most of the stone a nation hammers goes toward
its tomb only. It buries itself alive. As for the Pyramids, there is
nothing to wonder at in them so much as the fact that so many men could
be found degraded enough to spend their lives constructing a tomb for
some ambitious booby, whom it would have been wiser and manlier to have
drowned in the Nile, and then given his body to the dogs. I might
possibly invent some excuse for them and him, but I have no time for
it. As for the religion and love of art of the builders, it is much the
same all the world over, whether the building be an Egyptian temple or
the United States Bank. It costs more than it comes to. The mainspring
is vanity, assisted by the love of garlic and bread and butter. Mr.
Balcom, a promising young architect, designs it on the back of his
Vitruvius, with hard pencil and ruler, and the job is let out to Dobson
& Sons, stonecutters. When the thirty centuries begin to look down on
it, mankind begin to look up at it. As for your high towers and
monuments, there was a crazy fellow once in this town who undertook to
dig through to China, and he got so far that, as he said, he heard the
Chinese pots and kettles rattle; but I think that I shall not go out of
my way to admire the hole which he made. Many are concerned about the
monuments of the West and the East,—to know who built them. For my
part, I should like to know who in those days did not build them,—who
were above such trifling. But to proceed with my statistics.

By surveying, carpentry, and day-labor of various other kinds in the
village in the mean while, for I have as many trades as fingers, I had
earned $13.34. The expense of food for eight months, namely, from July
4th to March 1st, the time when these estimates were made, though I
lived there more than two years,—not counting potatoes, a little green
corn, and some peas, which I had raised, nor considering the value of
what was on hand at the last date, was


    Rice,................... $ 1.73½
    Molasses,................  1.73     Cheapest form of the
                                         saccharine.
    Rye meal,................  1.04¾
    Indian meal,.............  0.99¾     Cheaper than rye.
    Pork,....................  0.22

    All experiments which failed:
    Flour,...................  0.88  Costs more than Indian meal,
                                      both money and trouble.
    Sugar,...................  0.80
    Lard,....................  0.65
    Apples,..................  0.25
    Dried apple,.............  0.22
    Sweet potatoes,..........  0.10
    One pumpkin,.............  0.06
    One watermelon,..........  0.02
    Salt,....................  0.03

Yes, I did eat $8.74, all told; but I should not thus unblushingly
publish my guilt, if I did not know that most of my readers were
equally guilty with myself, and that their deeds would look no better
in print. The next year I sometimes caught a mess of fish for my
dinner, and once I went so far as to slaughter a woodchuck which
ravaged my bean-field,—effect his transmigration, as a Tartar would
say,—and devour him, partly for experiment’s sake; but though it
afforded me a momentary enjoyment, notwithstanding a musky flavor, I
saw that the longest use would not make that a good practice, however
it might seem to have your woodchucks ready dressed by the village
butcher.

Clothing and some incidental expenses within the same dates, though
little can be inferred from this item, amounted to

                                            $8.40¾
    Oil and some household utensils,.......  2.00

So that all the pecuniary outgoes, excepting for washing and mending,
which for the most part were done out of the house, and their bills
have not yet been received,—and these are all and more than all the
ways by which money necessarily goes out in this part of the
world,—were

    House,................................ $ 28.12½
    Farm one year,.......................... 14.72½
    Food eight months,......................  8.74
    Clothing, etc., eight months,...........  8.40¾
    Oil, &c., eight months,.................  2.00
                                           ——————
        In all,........................... $ 61.99¾

I address myself now to those of my readers who have a living to get.
And to meet this I have for farm produce sold

                                            $23.44
    Earned by day-labor,...................  13.34
                                           ——————
        In all,............................ $36.78,

which subtracted from the sum of the outgoes leaves a balance of
$25.21¾ on the one side,—this being very nearly the means with which I
started, and the measure of expenses to be incurred,—and on the other,
beside the leisure and independence and health thus secured, a
comfortable house for me as long as I choose to occupy it.

These statistics, however accidental and therefore uninstructive they
may appear, as they have a certain completeness, have a certain value
also. Nothing was given me of which I have not rendered some account.
It appears from the above estimate, that my food alone cost me in money
about twenty-seven cents a week. It was, for nearly two years after
this, rye and Indian meal without yeast, potatoes, rice, a very little
salt pork, molasses, and salt, and my drink water. It was fit that I
should live on rice, mainly, who loved so well the philosophy of India.
To meet the objections of some inveterate cavillers, I may as well
state, that if I dined out occasionally, as I always had done, and I
trust shall have opportunities to do again, it was frequently to the
detriment of my domestic arrangements. But the dining out, being, as I
have stated, a constant element, does not in the least affect a
comparative statement like this.

I learned from my two years’ experience that it would cost incredibly
little trouble to obtain one’s necessary food, even in this latitude;
that a man may use as simple a diet as the animals, and yet retain
health and strength. I have made a satisfactory dinner, satisfactory on
several accounts, simply off a dish of purslane (_Portulaca oleracea_)
which I gathered in my cornfield, boiled and salted. I give the Latin
on account of the savoriness of the trivial name. And pray what more
can a reasonable man desire, in peaceful times, in ordinary noons, than
a sufficient number of ears of green sweet-corn boiled, with the
addition of salt? Even the little variety which I used was a yielding
to the demands of appetite, and not of health. Yet men have come to
such a pass that they frequently starve, not for want of necessaries,
but for want of luxuries; and I know a good woman who thinks that her
son lost his life because he took to drinking water only.

The reader will perceive that I am treating the subject rather from an
economic than a dietetic point of view, and he will not venture to put
my abstemiousness to the test unless he has a well-stocked larder.

Bread I at first made of pure Indian meal and salt, genuine hoe-cakes,
which I baked before my fire out of doors on a shingle or the end of a
stick of timber sawed off in building my house; but it was wont to get
smoked and to have a piny flavor. I tried flour also; but have at last
found a mixture of rye and Indian meal most convenient and agreeable.
In cold weather it was no little amusement to bake several small loaves
of this in succession, tending and turning them as carefully as an
Egyptian his hatching eggs. They were a real cereal fruit which I
ripened, and they had to my senses a fragrance like that of other noble
fruits, which I kept in as long as possible by wrapping them in cloths.
I made a study of the ancient and indispensable art of bread-making,
consulting such authorities as offered, going back to the primitive
days and first invention of the unleavened kind, when from the wildness
of nuts and meats men first reached the mildness and refinement of this
diet, and travelling gradually down in my studies through that
accidental souring of the dough which, it is supposed, taught the
leavening process, and through the various fermentations thereafter,
till I came to “good, sweet, wholesome bread,” the staff of life.
Leaven, which some deem the soul of bread, the _spiritus_ which fills
its cellular tissue, which is religiously preserved like the vestal
fire,—some precious bottle-full, I suppose, first brought over in the
Mayflower, did the business for America, and its influence is still
rising, swelling, spreading, in cerealian billows over the land,—this
seed I regularly and faithfully procured from the village, till at
length one morning I forgot the rules, and scalded my yeast; by which
accident I discovered that even this was not indispensable,—for my
discoveries were not by the synthetic but analytic process,—and I have
gladly omitted it since, though most housewives earnestly assured me
that safe and wholesome bread without yeast might not be, and elderly
people prophesied a speedy decay of the vital forces. Yet I find it not
to be an essential ingredient, and after going without it for a year am
still in the land of the living; and I am glad to escape the
trivialness of carrying a bottle-full in my pocket, which would
sometimes pop and discharge its contents to my discomfiture. It is
simpler and more respectable to omit it. Man is an animal who more than
any other can adapt himself to all climates and circumstances. Neither
did I put any sal soda, or other acid or alkali, into my bread. It
would seem that I made it according to the recipe which Marcus Porcius
Cato gave about two centuries before Christ. “Panem depsticium sic
facito. Manus mortariumque bene lavato. Farinam in mortarium indito,
aquæ paulatim addito, subigitoque pulchre. Ubi bene subegeris,
defingito, coquitoque sub testu.” Which I take to mean—“Make kneaded
bread thus. Wash your hands and trough well. Put the meal into the
trough, add water gradually, and knead it thoroughly. When you have
kneaded it well, mould it, and bake it under a cover,” that is, in a
baking-kettle. Not a word about leaven. But I did not always use this
staff of life. At one time, owing to the emptiness of my purse, I saw
none of it for more than a month.

Every New Englander might easily raise all his own breadstuffs in this
land of rye and Indian corn, and not depend on distant and fluctuating
markets for them. Yet so far are we from simplicity and independence
that, in Concord, fresh and sweet meal is rarely sold in the shops, and
hominy and corn in a still coarser form are hardly used by any. For the
most part the farmer gives to his cattle and hogs the grain of his own
producing, and buys flour, which is at least no more wholesome, at a
greater cost, at the store. I saw that I could easily raise my bushel
or two of rye and Indian corn, for the former will grow on the poorest
land, and the latter does not require the best, and grind them in a
hand-mill, and so do without rice and pork; and if I must have some
concentrated sweet, I found by experiment that I could make a very good
molasses either of pumpkins or beets, and I knew that I needed only to
set out a few maples to obtain it more easily still, and while these
were growing I could use various substitutes beside those which I have
named. “For,” as the Forefathers sang,—

     “we can make liquor to sweeten our lips
     Of pumpkins and parsnips and walnut-tree chips.”

Finally, as for salt, that grossest of groceries, to obtain this might
be a fit occasion for a visit to the seashore, or, if I did without it
altogether, I should probably drink the less water. I do not learn that
the Indians ever troubled themselves to go after it.

Thus I could avoid all trade and barter, so far as my food was
concerned, and having a shelter already, it would only remain to get
clothing and fuel. The pantaloons which I now wear were woven in a
farmer’s family,—thank Heaven there is so much virtue still in man; for
I think the fall from the farmer to the operative as great and
memorable as that from the man to the farmer;—and in a new country,
fuel is an encumbrance. As for a habitat, if I were not permitted still
to squat, I might purchase one acre at the same price for which the
land I cultivated was sold—namely, eight dollars and eight cents. But
as it was, I considered that I enhanced the value of the land by
squatting on it.

There is a certain class of unbelievers who sometimes ask me such
questions as, if I think that I can live on vegetable food alone; and
to strike at the root of the matter at once,—for the root is faith,—I
am accustomed to answer such, that I can live on board nails. If they
cannot understand that, they cannot understand much that I have to say.
For my part, I am glad to hear of experiments of this kind being tried;
as that a young man tried for a fortnight to live on hard, raw corn on
the ear, using his teeth for all mortar. The squirrel tribe tried the
same and succeeded. The human race is interested in these experiments,
though a few old women who are incapacitated for them, or who own their
thirds in mills, may be alarmed.



My furniture, part of which I made myself, and the rest cost me nothing
of which I have not rendered an account, consisted of a bed, a table, a
desk, three chairs, a looking-glass three inches in diameter, a pair of
tongs and andirons, a kettle, a skillet, and a frying-pan, a dipper, a
wash-bowl, two knives and forks, three plates, one cup, one spoon, a
jug for oil, a jug for molasses, and a japanned lamp. None is so poor
that he need sit on a pumpkin. That is shiftlessness. There is a plenty
of such chairs as I like best in the village garrets to be had for
taking them away. Furniture! Thank God, I can sit and I can stand
without the aid of a furniture warehouse. What man but a philosopher
would not be ashamed to see his furniture packed in a cart and going up
country exposed to the light of heaven and the eyes of men, a beggarly
account of empty boxes? That is Spaulding’s furniture. I could never
tell from inspecting such a load whether it belonged to a so called
rich man or a poor one; the owner always seemed poverty-stricken.
Indeed, the more you have of such things the poorer you are. Each load
looks as if it contained the contents of a dozen shanties; and if one
shanty is poor, this is a dozen times as poor. Pray, for what do we
_move_ ever but to get rid of our furniture, our _exuviæ_; at last to
go from this world to another newly furnished, and leave this to be
burned? It is the same as if all these traps were buckled to a man’s
belt, and he could not move over the rough country where our lines are
cast without dragging them,—dragging his trap. He was a lucky fox that
left his tail in the trap. The muskrat will gnaw his third leg off to
be free. No wonder man has lost his elasticity. How often he is at a
dead set! “Sir, if I may be so bold, what do you mean by a dead set?”
If you are a seer, whenever you meet a man you will see all that he
owns, ay, and much that he pretends to disown, behind him, even to his
kitchen furniture and all the trumpery which he saves and will not
burn, and he will appear to be harnessed to it and making what headway
he can. I think that the man is at a dead set who has got through a
knot hole or gateway where his sledge load of furniture cannot follow
him. I cannot but feel compassion when I hear some trig,
compact-looking man, seemingly free, all girded and ready, speak of his
“furniture,” as whether it is insured or not. “But what shall I do with
my furniture?” My gay butterfly is entangled in a spider’s web then.
Even those who seem for a long while not to have any, if you inquire
more narrowly you will find have some stored in somebody’s barn. I look
upon England to-day as an old gentleman who is travelling with a great
deal of baggage, trumpery which has accumulated from long housekeeping,
which he has not the courage to burn; great trunk, little trunk,
bandbox and bundle. Throw away the first three at least. It would
surpass the powers of a well man nowadays to take up his bed and walk,
and I should certainly advise a sick one to lay down his bed and run.
When I have met an immigrant tottering under a bundle which contained
his all—looking like an enormous wen which had grown out of the nape of
his neck—I have pitied him, not because that was his all, but because
he had all _that_ to carry. If I have got to drag my trap, I will take
care that it be a light one and do not nip me in a vital part. But
perchance it would be wisest never to put one’s paw into it.

I would observe, by the way, that it costs me nothing for curtains, for
I have no gazers to shut out but the sun and moon, and I am willing
that they should look in. The moon will not sour milk nor taint meat of
mine, nor will the sun injure my furniture or fade my carpet, and if he
is sometimes too warm a friend, I find it still better economy to
retreat behind some curtain which nature has provided, than to add a
single item to the details of housekeeping. A lady once offered me a
mat, but as I had no room to spare within the house, nor time to spare
within or without to shake it, I declined it, preferring to wipe my
feet on the sod before my door. It is best to avoid the beginnings of
evil.

Not long since I was present at the auction of a deacon’s effects, for
his life had not been ineffectual:—

     “The evil that men do lives after them.”

As usual, a great proportion was trumpery which had begun to accumulate
in his father’s day. Among the rest was a dried tapeworm. And now,
after lying half a century in his garret and other dust holes, these
things were not burned; instead of a _bonfire_, or purifying
destruction of them, there was an _auction_, or increasing of them. The
neighbors eagerly collected to view them, bought them all, and
carefully transported them to their garrets and dust holes, to lie
there till their estates are settled, when they will start again. When
a man dies he kicks the dust.

The customs of some savage nations might, perchance, be profitably
imitated by us, for they at least go through the semblance of casting
their slough annually; they have the idea of the thing, whether they
have the reality or not. Would it not be well if we were to celebrate
such a “busk,” or “feast of first fruits,” as Bartram describes to have
been the custom of the Mucclasse Indians? “When a town celebrates the
busk,” says he, “having previously provided themselves with new
clothes, new pots, pans, and other household utensils and furniture,
they collect all their worn out clothes and other despicable things,
sweep and cleanse their houses, squares, and the whole town of their
filth, which with all the remaining grain and other old provisions they
cast together into one common heap, and consume it with fire. After
having taken medicine, and fasted for three days, all the fire in the
town is extinguished. During this fast they abstain from the
gratification of every appetite and passion whatever. A general amnesty
is proclaimed; all malefactors may return to their town.—”

“On the fourth morning, the high priest, by rubbing dry wood together,
produces new fire in the public square, from whence every habitation in
the town is supplied with the new and pure flame.”

They then feast on the new corn and fruits, and dance and sing for
three days, “and the four following days they receive visits and
rejoice with their friends from neighboring towns who have in like
manner purified and prepared themselves.”

The Mexicans also practised a similar purification at the end of every
fifty-two years, in the belief that it was time for the world to come
to an end.

I have scarcely heard of a truer sacrament, that is, as the dictionary
defines it, “outward and visible sign of an inward and spiritual
grace,” than this, and I have no doubt that they were originally
inspired directly from Heaven to do thus, though they have no biblical
record of the revelation.



For more than five years I maintained myself thus solely by the labor
of my hands, and I found, that by working about six weeks in a year, I
could meet all the expenses of living. The whole of my winters, as well
as most of my summers, I had free and clear for study. I have
thoroughly tried school-keeping, and found that my expenses were in
proportion, or rather out of proportion, to my income, for I was
obliged to dress and train, not to say think and believe, accordingly,
and I lost my time into the bargain. As I did not teach for the good of
my fellow-men, but simply for a livelihood, this was a failure. I have
tried trade; but I found that it would take ten years to get under way
in that, and that then I should probably be on my way to the devil. I
was actually afraid that I might by that time be doing what is called a
good business. When formerly I was looking about to see what I could do
for a living, some sad experience in conforming to the wishes of
friends being fresh in my mind to tax my ingenuity, I thought often and
seriously of picking huckleberries; that surely I could do, and its
small profits might suffice,—for my greatest skill has been to want but
little,—so little capital it required, so little distraction from my
wonted moods, I foolishly thought. While my acquaintances went
unhesitatingly into trade or the professions, I contemplated this
occupation as most like theirs; ranging the hills all summer to pick
the berries which came in my way, and thereafter carelessly dispose of
them; so, to keep the flocks of Admetus. I also dreamed that I might
gather the wild herbs, or carry evergreens to such villagers as loved
to be reminded of the woods, even to the city, by hay-cart loads. But I
have since learned that trade curses everything it handles; and though
you trade in messages from heaven, the whole curse of trade attaches to
the business.

As I preferred some things to others, and especially valued my freedom,
as I could fare hard and yet succeed well, I did not wish to spend my
time in earning rich carpets or other fine furniture, or delicate
cookery, or a house in the Grecian or the Gothic style just yet. If
there are any to whom it is no interruption to acquire these things,
and who know how to use them when acquired, I relinquish to them the
pursuit. Some are “industrious,” and appear to love labor for its own
sake, or perhaps because it keeps them out of worse mischief; to such I
have at present nothing to say. Those who would not know what to do
with more leisure than they now enjoy, I might advise to work twice as
hard as they do,—work till they pay for themselves, and get their free
papers. For myself I found that the occupation of a day-laborer was the
most independent of any, especially as it required only thirty or forty
days in a year to support one. The laborer’s day ends with the going
down of the sun, and he is then free to devote himself to his chosen
pursuit, independent of his labor; but his employer, who speculates
from month to month, has no respite from one end of the year to the
other.

In short, I am convinced, both by faith and experience, that to
maintain one’s self on this earth is not a hardship but a pastime, if
we will live simply and wisely; as the pursuits of the simpler nations
are still the sports of the more artificial. It is not necessary that a
man should earn his living by the sweat of his brow, unless he sweats
easier than I do.

One young man of my acquaintance, who has inherited some acres, told me
that he thought he should live as I did, _if he had the means_. I would
not have any one adopt _my_ mode of living on any account; for, beside
that before he has fairly learned it I may have found out another for
myself, I desire that there may be as many different persons in the
world as possible; but I would have each one be very careful to find
out and pursue _his own_ way, and not his father’s or his mother’s or
his neighbor’s instead. The youth may build or plant or sail, only let
him not be hindered from doing that which he tells me he would like to
do. It is by a mathematical point only that we are wise, as the sailor
or the fugitive slave keeps the polestar in his eye; but that is
sufficient guidance for all our life. We may not arrive at our port
within a calculable period, but we would preserve the true course.

Undoubtedly, in this case, what is true for one is truer still for a
thousand, as a large house is not proportionally more expensive than a
small one, since one roof may cover, one cellar underlie, and one wall
separate several apartments. But for my part, I preferred the solitary
dwelling. Moreover, it will commonly be cheaper to build the whole
yourself than to convince another of the advantage of the common wall;
and when you have done this, the common partition, to be much cheaper,
must be a thin one, and that other may prove a bad neighbor, and also
not keep his side in repair. The only coöperation which is commonly
possible is exceedingly partial and superficial; and what little true
coöperation there is, is as if it were not, being a harmony inaudible
to men. If a man has faith, he will coöperate with equal faith
everywhere; if he has not faith, he will continue to live like the rest
of the world, whatever company he is joined to. To coöperate, in the
highest as well as the lowest sense, means _to get our living
together_. I heard it proposed lately that two young men should travel
together over the world, the one without money, earning his means as he
went, before the mast and behind the plow, the other carrying a bill of
exchange in his pocket. It was easy to see that they could not long be
companions or coöperate, since one would not _operate_ at all. They
would part at the first interesting crisis in their adventures. Above
all, as I have implied, the man who goes alone can start to-day; but he
who travels with another must wait till that other is ready, and it may
be a long time before they get off.



But all this is very selfish, I have heard some of my townsmen say. I
confess that I have hitherto indulged very little in philanthropic
enterprises. I have made some sacrifices to a sense of duty, and among
others have sacrificed this pleasure also. There are those who have
used all their arts to persuade me to undertake the support of some
poor family in the town; and if I had nothing to do,—for the devil
finds employment for the idle,—I might try my hand at some such pastime
as that. However, when I have thought to indulge myself in this
respect, and lay their Heaven under an obligation by maintaining
certain poor persons in all respects as comfortably as I maintain
myself, and have even ventured so far as to make them the offer, they
have one and all unhesitatingly preferred to remain poor. While my
townsmen and women are devoted in so many ways to the good of their
fellows, I trust that one at least may be spared to other and less
humane pursuits. You must have a genius for charity as well as for any
thing else. As for Doing-good, that is one of the professions which are
full. Moreover, I have tried it fairly, and, strange as it may seem, am
satisfied that it does not agree with my constitution. Probably I
should not consciously and deliberately forsake my particular calling
to do the good which society demands of me, to save the universe from
annihilation; and I believe that a like but infinitely greater
steadfastness elsewhere is all that now preserves it. But I would not
stand between any man and his genius; and to him who does this work,
which I decline, with his whole heart and soul and life, I would say,
Persevere, even if the world call it doing evil, as it is most likely
they will.

I am far from supposing that my case is a peculiar one; no doubt many
of my readers would make a similar defence. At doing something,—I will
not engage that my neighbors shall pronounce it good,—I do not hesitate
to say that I should be a capital fellow to hire; but what that is, it
is for my employer to find out. What _good_ I do, in the common sense
of that word, must be aside from my main path, and for the most part
wholly unintended. Men say, practically, Begin where you are and such
as you are, without aiming mainly to become of more worth, and with
kindness aforethought go about doing good. If I were to preach at all
in this strain, I should say rather, Set about being good. As if the
sun should stop when he had kindled his fires up to the splendor of a
moon or a star of the sixth magnitude, and go about like a Robin
Goodfellow, peeping in at every cottage window, inspiring lunatics, and
tainting meats, and making darkness visible, instead of steadily
increasing his genial heat and beneficence till he is of such
brightness that no mortal can look him in the face, and then, and in
the mean while too, going about the world in his own orbit, doing it
good, or rather, as a truer philosophy has discovered, the world going
about him getting good. When Phaeton, wishing to prove his heavenly
birth by his beneficence, had the sun’s chariot but one day, and drove
out of the beaten track, he burned several blocks of houses in the
lower streets of heaven, and scorched the surface of the earth, and
dried up every spring, and made the great desert of Sahara, till at
length Jupiter hurled him headlong to the earth with a thunderbolt, and
the sun, through grief at his death, did not shine for a year.

There is no odor so bad as that which arises from goodness tainted. It
is human, it is divine, carrion. If I knew for a certainty that a man
was coming to my house with the conscious design of doing me good, I
should run for my life, as from that dry and parching wind of the
African deserts called the simoom, which fills the mouth and nose and
ears and eyes with dust till you are suffocated, for fear that I should
get some of his good done to me,—some of its virus mingled with my
blood. No,—in this case I would rather suffer evil the natural way. A
man is not a good _man_ to me because he will feed me if I should be
starving, or warm me if I should be freezing, or pull me out of a ditch
if I should ever fall into one. I can find you a Newfoundland dog that
will do as much. Philanthropy is not love for one’s fellow-man in the
broadest sense. Howard was no doubt an exceedingly kind and worthy man
in his way, and has his reward; but, comparatively speaking, what are a
hundred Howards to _us_, if their philanthropy do not help _us_ in our
best estate, when we are most worthy to be helped? I never heard of a
philanthropic meeting in which it was sincerely proposed to do any good
to me, or the like of me.

The Jesuits were quite balked by those Indians who, being burned at the
stake, suggested new modes of torture to their tormentors. Being
superior to physical suffering, it sometimes chanced that they were
superior to any consolation which the missionaries could offer; and the
law to do as you would be done by fell with less persuasiveness on the
ears of those who, for their part, did not care how they were done by,
who loved their enemies after a new fashion, and came very near freely
forgiving them all they did.

Be sure that you give the poor the aid they most need, though it be
your example which leaves them far behind. If you give money, spend
yourself with it, and do not merely abandon it to them. We make curious
mistakes sometimes. Often the poor man is not so cold and hungry as he
is dirty and ragged and gross. It is partly his taste, and not merely
his misfortune. If you give him money, he will perhaps buy more rags
with it. I was wont to pity the clumsy Irish laborers who cut ice on
the pond, in such mean and ragged clothes, while I shivered in my more
tidy and somewhat more fashionable garments, till, one bitter cold day,
one who had slipped into the water came to my house to warm him, and I
saw him strip off three pairs of pants and two pairs of stockings ere
he got down to the skin, though they were dirty and ragged enough, it
is true, and that he could afford to refuse the _extra_ garments which
I offered him, he had so many _intra_ ones. This ducking was the very
thing he needed. Then I began to pity myself, and I saw that it would
be a greater charity to bestow on me a flannel shirt than a whole
slop-shop on him. There are a thousand hacking at the branches of evil
to one who is striking at the root, and it may be that he who bestows
the largest amount of time and money on the needy is doing the most by
his mode of life to produce that misery which he strives in vain to
relieve. It is the pious slave-breeder devoting the proceeds of every
tenth slave to buy a Sunday’s liberty for the rest. Some show their
kindness to the poor by employing them in their kitchens. Would they
not be kinder if they employed themselves there? You boast of spending
a tenth part of your income in charity; maybe you should spend the nine
tenths so, and done with it. Society recovers only a tenth part of the
property then. Is this owing to the generosity of him in whose
possession it is found, or to the remissness of the officers of
justice?

Philanthropy is almost the only virtue which is sufficiently
appreciated by mankind. Nay, it is greatly overrated; and it is our
selfishness which overrates it. A robust poor man, one sunny day here
in Concord, praised a fellow-townsman to me, because, as he said, he
was kind to the poor; meaning himself. The kind uncles and aunts of the
race are more esteemed than its true spiritual fathers and mothers. I
once heard a reverend lecturer on England, a man of learning and
intelligence, after enumerating her scientific, literary, and political
worthies, Shakespeare, Bacon, Cromwell, Milton, Newton, and others,
speak next of her Christian heroes, whom, as if his profession required
it of him, he elevated to a place far above all the rest, as the
greatest of the great. They were Penn, Howard, and Mrs. Fry. Every one
must feel the falsehood and cant of this. The last were not England’s
best men and women; only, perhaps, her best philanthropists.

I would not subtract any thing from the praise that is due to
philanthropy, but merely demand justice for all who by their lives and
works are a blessing to mankind. I do not value chiefly a man’s
uprightness and benevolence, which are, as it were, his stem and
leaves. Those plants of whose greenness withered we make herb tea for
the sick, serve but a humble use, and are most employed by quacks. I
want the flower and fruit of a man; that some fragrance be wafted over
from him to me, and some ripeness flavor our intercourse. His goodness
must not be a partial and transitory act, but a constant superfluity,
which costs him nothing and of which he is unconscious. This is a
charity that hides a multitude of sins. The philanthropist too often
surrounds mankind with the remembrance of his own cast-off griefs as an
atmosphere, and calls it sympathy. We should impart our courage, and
not our despair, our health and ease, and not our disease, and take
care that this does not spread by contagion. From what southern plains
comes up the voice of wailing? Under what latitudes reside the heathen
to whom we would send light? Who is that intemperate and brutal man
whom we would redeem? If any thing ail a man, so that he does not
perform his functions, if he have a pain in his bowels even,—for that
is the seat of sympathy,—he forthwith sets about reforming—the world.
Being a microcosm himself, he discovers, and it is a true discovery,
and he is the man to make it,—that the world has been eating green
apples; to his eyes, in fact, the globe itself is a great green apple,
which there is danger awful to think of that the children of men will
nibble before it is ripe; and straightway his drastic philanthropy
seeks out the Esquimaux and the Patagonian, and embraces the populous
Indian and Chinese villages; and thus, by a few years of philanthropic
activity, the powers in the mean while using him for their own ends, no
doubt, he cures himself of his dyspepsia, the globe acquires a faint
blush on one or both of its cheeks, as if it were beginning to be ripe,
and life loses its crudity and is once more sweet and wholesome to
live. I never dreamed of any enormity greater than I have committed. I
never knew, and never shall know, a worse man than myself.

I believe that what so saddens the reformer is not his sympathy with
his fellows in distress, but, though he be the holiest son of God, is
his private ail. Let this be righted, let the spring come to him, the
morning rise over his couch, and he will forsake his generous
companions without apology. My excuse for not lecturing against the use
of tobacco is, that I never chewed it; that is a penalty which reformed
tobacco-chewers have to pay; though there are things enough I have
chewed, which I could lecture against. If you should ever be betrayed
into any of these philanthropies, do not let your left hand know what
your right hand does, for it is not worth knowing. Rescue the drowning
and tie your shoe-strings. Take your time, and set about some free
labor.

Our manners have been corrupted by communication with the saints. Our
hymn-books resound with a melodious cursing of God and enduring him
forever. One would say that even the prophets and redeemers had rather
consoled the fears than confirmed the hopes of man. There is nowhere
recorded a simple and irrepressible satisfaction with the gift of life,
any memorable praise of God. All health and success does me good,
however far off and withdrawn it may appear; all disease and failure
helps to make me sad and does me evil, however much sympathy it may
have with me or I with it. If, then, we would indeed restore mankind by
truly Indian, botanic, magnetic, or natural means, let us first be as
simple and well as Nature ourselves, dispel the clouds which hang over
our own brows, and take up a little life into our pores. Do not stay to
be an overseer of the poor, but endeavor to become one of the worthies
of the world.

I read in the Gulistan, or Flower Garden, of Sheik Sadi of Shiraz, that
“They asked a wise man, saying; Of the many celebrated trees which the
Most High God has created lofty and umbrageous, they call none azad, or
free, excepting the cypress, which bears no fruit; what mystery is
there in this? He replied; Each has its appropriate produce, and
appointed season, during the continuance of which it is fresh and
blooming, and during their absence dry and withered; to neither of
which states is the cypress exposed, being always flourishing; and of
this nature are the azads, or religious independents.—Fix not thy heart
on that which is transitory; for the Dijlah, or Tigris, will continue
to flow through Bagdad after the race of caliphs is extinct: if thy
hand has plenty, be liberal as the date tree; but if it affords nothing
to give away, be an azad, or free man, like the cypress.”

     COMPLEMENTAL VERSES

     The Pretensions of Poverty

     “Thou dost presume too much, poor needy wretch,
     To claim a station in the firmament
     Because thy humble cottage, or thy tub,
     Nurses some lazy or pedantic virtue
     In the cheap sunshine or by shady springs,
     With roots and pot-herbs; where thy right hand,
     Tearing those humane passions from the mind,
     Upon whose stocks fair blooming virtues flourish,
     Degradeth nature, and benumbeth sense,
     And, Gorgon-like, turns active men to stone.
     We not require the dull society
     Of your necessitated temperance,
     Or that unnatural stupidity
     That knows nor joy nor sorrow; nor your forc’d
     Falsely exalted passive fortitude
     Above the active. This low abject brood,
     That fix their seats in mediocrity,
     Become your servile minds; but we advance
     Such virtues only as admit excess,
     Brave, bounteous acts, regal magnificence,
     All-seeing prudence, magnanimity
     That knows no bound, and that heroic virtue
     For which antiquity hath left no name,
     But patterns only, such as Hercules,
     Achilles, Theseus. Back to thy loath’d cell;
     And when thou seest the new enlightened sphere,
     Study to know but what those worthies were.”
                                    T. CAREW


Where I Lived, and What I Lived For

At a certain season of our life we are accustomed to consider every
spot as the possible site of a house. I have thus surveyed the country
on every side within a dozen miles of where I live. In imagination I
have bought all the farms in succession, for all were to be bought, and
I knew their price. I walked over each farmer’s premises, tasted his
wild apples, discoursed on husbandry with him, took his farm at his
price, at any price, mortgaging it to him in my mind; even put a higher
price on it,—took everything but a deed of it,—took his word for his
deed, for I dearly love to talk,—cultivated it, and him too to some
extent, I trust, and withdrew when I had enjoyed it long enough,
leaving him to carry it on. This experience entitled me to be regarded
as a sort of real-estate broker by my friends. Wherever I sat, there I
might live, and the landscape radiated from me accordingly. What is a
house but a _sedes_, a seat?—better if a country seat. I discovered
many a site for a house not likely to be soon improved, which some
might have thought too far from the village, but to my eyes the village
was too far from it. Well, there I might live, I said; and there I did
live, for an hour, a summer and a winter life; saw how I could let the
years run off, buffet the winter through, and see the spring come in.
The future inhabitants of this region, wherever they may place their
houses, may be sure that they have been anticipated. An afternoon
sufficed to lay out the land into orchard, woodlot, and pasture, and to
decide what fine oaks or pines should be left to stand before the door,
and whence each blasted tree could be seen to the best advantage; and
then I let it lie, fallow perchance, for a man is rich in proportion to
the number of things which he can afford to let alone.

My imagination carried me so far that I even had the refusal of several
farms,—the refusal was all I wanted,—but I never got my fingers burned
by actual possession. The nearest that I came to actual possession was
when I bought the Hollowell place, and had begun to sort my seeds, and
collected materials with which to make a wheelbarrow to carry it on or
off with; but before the owner gave me a deed of it, his wife—every man
has such a wife—changed her mind and wished to keep it, and he offered
me ten dollars to release him. Now, to speak the truth, I had but ten
cents in the world, and it surpassed my arithmetic to tell, if I was
that man who had ten cents, or who had a farm, or ten dollars, or all
together. However, I let him keep the ten dollars and the farm too, for
I had carried it far enough; or rather, to be generous, I sold him the
farm for just what I gave for it, and, as he was not a rich man, made
him a present of ten dollars, and still had my ten cents, and seeds,
and materials for a wheelbarrow left. I found thus that I had been a
rich man without any damage to my poverty. But I retained the
landscape, and I have since annually carried off what it yielded
without a wheelbarrow. With respect to landscapes,—

     “I am monarch of all I _survey_,
     My right there is none to dispute.”

I have frequently seen a poet withdraw, having enjoyed the most
valuable part of a farm, while the crusty farmer supposed that he had
got a few wild apples only. Why, the owner does not know it for many
years when a poet has put his farm in rhyme, the most admirable kind of
invisible fence, has fairly impounded it, milked it, skimmed it, and
got all the cream, and left the farmer only the skimmed milk.

The real attractions of the Hollowell farm, to me, were; its complete
retirement, being, about two miles from the village, half a mile from
the nearest neighbor, and separated from the highway by a broad field;
its bounding on the river, which the owner said protected it by its
fogs from frosts in the spring, though that was nothing to me; the gray
color and ruinous state of the house and barn, and the dilapidated
fences, which put such an interval between me and the last occupant;
the hollow and lichen-covered apple trees, gnawed by rabbits, showing
what kind of neighbors I should have; but above all, the recollection I
had of it from my earliest voyages up the river, when the house was
concealed behind a dense grove of red maples, through which I heard the
house-dog bark. I was in haste to buy it, before the proprietor
finished getting out some rocks, cutting down the hollow apple trees,
and grubbing up some young birches which had sprung up in the pasture,
or, in short, had made any more of his improvements. To enjoy these
advantages I was ready to carry it on; like Atlas, to take the world on
my shoulders,—I never heard what compensation he received for that,—and
do all those things which had no other motive or excuse but that I
might pay for it and be unmolested in my possession of it; for I knew
all the while that it would yield the most abundant crop of the kind I
wanted if I could only afford to let it alone. But it turned out as I
have said.

All that I could say, then, with respect to farming on a large scale,
(I have always cultivated a garden,) was, that I had had my seeds
ready. Many think that seeds improve with age. I have no doubt that
time discriminates between the good and the bad; and when at last I
shall plant, I shall be less likely to be disappointed. But I would say
to my fellows, once for all, As long as possible live free and
uncommitted. It makes but little difference whether you are committed
to a farm or the county jail.

Old Cato, whose “De Re Rusticâ” is my “Cultivator,” says, and the only
translation I have seen makes sheer nonsense of the passage, “When you
think of getting a farm, turn it thus in your mind, not to buy
greedily; nor spare your pains to look at it, and do not think it
enough to go round it once. The oftener you go there the more it will
please you, if it is good.” I think I shall not buy greedily, but go
round and round it as long as I live, and be buried in it first, that
it may please me the more at last.



The present was my next experiment of this kind, which I purpose to
describe more at length; for convenience, putting the experience of two
years into one. As I have said, I do not propose to write an ode to
dejection, but to brag as lustily as chanticleer in the morning,
standing on his roost, if only to wake my neighbors up.

When first I took up my abode in the woods, that is, began to spend my
nights as well as days there, which, by accident, was on Independence
Day, or the Fourth of July, 1845, my house was not finished for winter,
but was merely a defence against the rain, without plastering or
chimney, the walls being of rough, weather-stained boards, with wide
chinks, which made it cool at night. The upright white hewn studs and
freshly planed door and window casings gave it a clean and airy look,
especially in the morning, when its timbers were saturated with dew, so
that I fancied that by noon some sweet gum would exude from them. To my
imagination it retained throughout the day more or less of this auroral
character, reminding me of a certain house on a mountain which I had
visited the year before. This was an airy and unplastered cabin, fit to
entertain a travelling god, and where a goddess might trail her
garments. The winds which passed over my dwelling were such as sweep
over the ridges of mountains, bearing the broken strains, or celestial
parts only, of terrestrial music. The morning wind forever blows, the
poem of creation is uninterrupted; but few are the ears that hear it.
Olympus is but the outside of the earth every where.

The only house I had been the owner of before, if I except a boat, was
a tent, which I used occasionally when making excursions in the summer,
and this is still rolled up in my garret; but the boat, after passing
from hand to hand, has gone down the stream of time. With this more
substantial shelter about me, I had made some progress toward settling
in the world. This frame, so slightly clad, was a sort of
crystallization around me, and reacted on the builder. It was
suggestive somewhat as a picture in outlines. I did not need to go
outdoors to take the air, for the atmosphere within had lost none of
its freshness. It was not so much within doors as behind a door where I
sat, even in the rainiest weather. The Harivansa says, “An abode
without birds is like a meat without seasoning.” Such was not my abode,
for I found myself suddenly neighbor to the birds; not by having
imprisoned one, but having caged myself near them. I was not only
nearer to some of those which commonly frequent the garden and the
orchard, but to those wilder and more thrilling songsters of the forest
which never, or rarely, serenade a villager,—the wood-thrush, the
veery, the scarlet tanager, the field-sparrow, the whippoorwill, and
many others.

I was seated by the shore of a small pond, about a mile and a half
south of the village of Concord and somewhat higher than it, in the
midst of an extensive wood between that town and Lincoln, and about two
miles south of that our only field known to fame, Concord Battle
Ground; but I was so low in the woods that the opposite shore, half a
mile off, like the rest, covered with wood, was my most distant
horizon. For the first week, whenever I looked out on the pond it
impressed me like a tarn high up on the side of a mountain, its bottom
far above the surface of other lakes, and, as the sun arose, I saw it
throwing off its nightly clothing of mist, and here and there, by
degrees, its soft ripples or its smooth reflecting surface was
revealed, while the mists, like ghosts, were stealthily withdrawing in
every direction into the woods, as at the breaking up of some nocturnal
conventicle. The very dew seemed to hang upon the trees later into the
day than usual, as on the sides of mountains.

This small lake was of most value as a neighbor in the intervals of a
gentle rain storm in August, when, both air and water being perfectly
still, but the sky overcast, mid-afternoon had all the serenity of
evening, and the wood-thrush sang around, and was heard from shore to
shore. A lake like this is never smoother than at such a time; and the
clear portion of the air above it being shallow and darkened by clouds,
the water, full of light and reflections, becomes a lower heaven itself
so much the more important. From a hill top near by, where the wood had
been recently cut off, there was a pleasing vista southward across the
pond, through a wide indentation in the hills which form the shore
there, where their opposite sides sloping toward each other suggested a
stream flowing out in that direction through a wooded valley, but
stream there was none. That way I looked between and over the near
green hills to some distant and higher ones in the horizon, tinged with
blue. Indeed, by standing on tiptoe I could catch a glimpse of some of
the peaks of the still bluer and more distant mountain ranges in the
north-west, those true-blue coins from heaven’s own mint, and also of
some portion of the village. But in other directions, even from this
point, I could not see over or beyond the woods which surrounded me. It
is well to have some water in your neighborhood, to give buoyancy to
and float the earth. One value even of the smallest well is, that when
you look into it you see that earth is not continent but insular. This
is as important as that it keeps butter cool. When I looked across the
pond from this peak toward the Sudbury meadows, which in time of flood
I distinguished elevated perhaps by a mirage in their seething valley,
like a coin in a basin, all the earth beyond the pond appeared like a
thin crust insulated and floated even by this small sheet of
interverting water, and I was reminded that this on which I dwelt was
but _dry land_.

Though the view from my door was still more contracted, I did not feel
crowded or confined in the least. There was pasture enough for my
imagination. The low shrub-oak plateau to which the opposite shore
arose, stretched away toward the prairies of the West and the steppes
of Tartary, affording ample room for all the roving families of men.
“There are none happy in the world but beings who enjoy freely a vast
horizon,”—said Damodara, when his herds required new and larger
pastures.

Both place and time were changed, and I dwelt nearer to those parts of
the universe and to those eras in history which had most attracted me.
Where I lived was as far off as many a region viewed nightly by
astronomers. We are wont to imagine rare and delectable places in some
remote and more celestial corner of the system, behind the
constellation of Cassiopeia’s Chair, far from noise and disturbance. I
discovered that my house actually had its site in such a withdrawn, but
forever new and unprofaned, part of the universe. If it were worth the
while to settle in those parts near to the Pleiades or the Hyades, to
Aldebaran or Altair, then I was really there, or at an equal remoteness
from the life which I had left behind, dwindled and twinkling with as
fine a ray to my nearest neighbor, and to be seen only in moonless
nights by him. Such was that part of creation where I had squatted;—

     “There was a shepherd that did live,
         And held his thoughts as high
     As were the mounts whereon his flocks
         Did hourly feed him by.”

What should we think of the shepherd’s life if his flocks always
wandered to higher pastures than his thoughts?

Every morning was a cheerful invitation to make my life of equal
simplicity, and I may say innocence, with Nature herself. I have been
as sincere a worshipper of Aurora as the Greeks. I got up early and
bathed in the pond; that was a religious exercise, and one of the best
things which I did. They say that characters were engraven on the
bathing tub of king Tching-thang to this effect: “Renew thyself
completely each day; do it again, and again, and forever again.” I can
understand that. Morning brings back the heroic ages. I was as much
affected by the faint hum of a mosquito making its invisible and
unimaginable tour through my apartment at earliest dawn, when I was
sitting with door and windows open, as I could be by any trumpet that
ever sang of fame. It was Homer’s requiem; itself an Iliad and Odyssey
in the air, singing its own wrath and wanderings. There was something
cosmical about it; a standing advertisement, till forbidden, of the
everlasting vigor and fertility of the world. The morning, which is the
most memorable season of the day, is the awakening hour. Then there is
least somnolence in us; and for an hour, at least, some part of us
awakes which slumbers all the rest of the day and night. Little is to
be expected of that day, if it can be called a day, to which we are not
awakened by our Genius, but by the mechanical nudgings of some
servitor, are not awakened by our own newly-acquired force and
aspirations from within, accompanied by the undulations of celestial
music, instead of factory bells, and a fragrance filling the air—to a
higher life than we fell asleep from; and thus the darkness bear its
fruit, and prove itself to be good, no less than the light. That man
who does not believe that each day contains an earlier, more sacred,
and auroral hour than he has yet profaned, has despaired of life, and
is pursuing a descending and darkening way. After a partial cessation
of his sensuous life, the soul of man, or its organs rather, are
reinvigorated each day, and his Genius tries again what noble life it
can make. All memorable events, I should say, transpire in morning time
and in a morning atmosphere. The Vedas say, “All intelligences awake
with the morning.” Poetry and art, and the fairest and most memorable
of the actions of men, date from such an hour. All poets and heroes,
like Memnon, are the children of Aurora, and emit their music at
sunrise. To him whose elastic and vigorous thought keeps pace with the
sun, the day is a perpetual morning. It matters not what the clocks say
or the attitudes and labors of men. Morning is when I am awake and
there is a dawn in me. Moral reform is the effort to throw off sleep.
Why is it that men give so poor an account of their day if they have
not been slumbering? They are not such poor calculators. If they had
not been overcome with drowsiness, they would have performed something.
The millions are awake enough for physical labor; but only one in a
million is awake enough for effective intellectual exertion, only one
in a hundred millions to a poetic or divine life. To be awake is to be
alive. I have never yet met a man who was quite awake. How could I have
looked him in the face?

We must learn to reawaken and keep ourselves awake, not by mechanical
aids, but by an infinite expectation of the dawn, which does not
forsake us in our soundest sleep. I know of no more encouraging fact
than the unquestionable ability of man to elevate his life by a
conscious endeavor. It is something to be able to paint a particular
picture, or to carve a statue, and so to make a few objects beautiful;
but it is far more glorious to carve and paint the very atmosphere and
medium through which we look, which morally we can do. To affect the
quality of the day, that is the highest of arts. Every man is tasked to
make his life, even in its details, worthy of the contemplation of his
most elevated and critical hour. If we refused, or rather used up, such
paltry information as we get, the oracles would distinctly inform us
how this might be done.

I went to the woods because I wished to live deliberately, to front
only the essential facts of life, and see if I could not learn what it
had to teach, and not, when I came to die, discover that I had not
lived. I did not wish to live what was not life, living is so dear; nor
did I wish to practise resignation, unless it was quite necessary. I
wanted to live deep and suck out all the marrow of life, to live so
sturdily and Spartan-like as to put to rout all that was not life, to
cut a broad swath and shave close, to drive life into a corner, and
reduce it to its lowest terms, and, if it proved to be mean, why then
to get the whole and genuine meanness of it, and publish its meanness
to the world; or if it were sublime, to know it by experience, and be
able to give a true account of it in my next excursion. For most men,
it appears to me, are in a strange uncertainty about it, whether it is
of the devil or of God, and have _somewhat hastily_ concluded that it
is the chief end of man here to “glorify God and enjoy him forever.”

Still we live meanly, like ants; though the fable tells us that we were
long ago changed into men; like pygmies we fight with cranes; it is
error upon error, and clout upon clout, and our best virtue has for its
occasion a superfluous and evitable wretchedness. Our life is frittered
away by detail. An honest man has hardly need to count more than his
ten fingers, or in extreme cases he may add his ten toes, and lump the
rest. Simplicity, simplicity, simplicity! I say, let your affairs be as
two or three, and not a hundred or a thousand; instead of a million
count half a dozen, and keep your accounts on your thumb nail. In the
midst of this chopping sea of civilized life, such are the clouds and
storms and quicksands and thousand-and-one items to be allowed for,
that a man has to live, if he would not founder and go to the bottom
and not make his port at all, by dead reckoning, and he must be a great
calculator indeed who succeeds. Simplify, simplify. Instead of three
meals a day, if it be necessary eat but one; instead of a hundred
dishes, five; and reduce other things in proportion. Our life is like a
German Confederacy, made up of petty states, with its boundary forever
fluctuating, so that even a German cannot tell you how it is bounded at
any moment. The nation itself, with all its so called internal
improvements, which, by the way are all external and superficial, is
just such an unwieldy and overgrown establishment, cluttered with
furniture and tripped up by its own traps, ruined by luxury and
heedless expense, by want of calculation and a worthy aim, as the
million households in the land; and the only cure for it as for them is
in a rigid economy, a stern and more than Spartan simplicity of life
and elevation of purpose. It lives too fast. Men think that it is
essential that the _Nation_ have commerce, and export ice, and talk
through a telegraph, and ride thirty miles an hour, without a doubt,
whether _they_ do or not; but whether we should live like baboons or
like men, is a little uncertain. If we do not get out sleepers, and
forge rails, and devote days and nights to the work, but go to
tinkering upon our _lives_ to improve _them_, who will build railroads?
And if railroads are not built, how shall we get to heaven in season?
But if we stay at home and mind our business, who will want railroads?
We do not ride on the railroad; it rides upon us. Did you ever think
what those sleepers are that underlie the railroad? Each one is a man,
an Irish-man, or a Yankee man. The rails are laid on them, and they are
covered with sand, and the cars run smoothly over them. They are sound
sleepers, I assure you. And every few years a new lot is laid down and
run over; so that, if some have the pleasure of riding on a rail,
others have the misfortune to be ridden upon. And when they run over a
man that is walking in his sleep, a supernumerary sleeper in the wrong
position, and wake him up, they suddenly stop the cars, and make a hue
and cry about it, as if this were an exception. I am glad to know that
it takes a gang of men for every five miles to keep the sleepers down
and level in their beds as it is, for this is a sign that they may
sometime get up again.

Why should we live with such hurry and waste of life? We are determined
to be starved before we are hungry. Men say that a stitch in time saves
nine, and so they take a thousand stitches to-day to save nine
to-morrow. As for _work_, we haven’t any of any consequence. We have
the Saint Vitus’ dance, and cannot possibly keep our heads still. If I
should only give a few pulls at the parish bell-rope, as for a fire,
that is, without setting the bell, there is hardly a man on his farm in
the outskirts of Concord, notwithstanding that press of engagements
which was his excuse so many times this morning, nor a boy, nor a
woman, I might almost say, but would forsake all and follow that sound,
not mainly to save property from the flames, but, if we will confess
the truth, much more to see it burn, since burn it must, and we, be it
known, did not set it on fire,—or to see it put out, and have a hand in
it, if that is done as handsomely; yes, even if it were the parish
church itself. Hardly a man takes a half hour’s nap after dinner, but
when he wakes he holds up his head and asks, “What’s the news?” as if
the rest of mankind had stood his sentinels. Some give directions to be
waked every half hour, doubtless for no other purpose; and then, to pay
for it, they tell what they have dreamed. After a night’s sleep the
news is as indispensable as the breakfast. “Pray tell me any thing new
that has happened to a man any where on this globe,”—and he reads it
over his coffee and rolls, that a man has had his eyes gouged out this
morning on the Wachito River; never dreaming the while that he lives in
the dark unfathomed mammoth cave of this world, and has but the
rudiment of an eye himself.

For my part, I could easily do without the post-office. I think that
there are very few important communications made through it. To speak
critically, I never received more than one or two letters in my life—I
wrote this some years ago—that were worth the postage. The penny-post
is, commonly, an institution through which you seriously offer a man
that penny for his thoughts which is so often safely offered in jest.
And I am sure that I never read any memorable news in a newspaper. If
we read of one man robbed, or murdered, or killed by accident, or one
house burned, or one vessel wrecked, or one steamboat blown up, or one
cow run over on the Western Railroad, or one mad dog killed, or one lot
of grasshoppers in the winter,—we never need read of another. One is
enough. If you are acquainted with the principle, what do you care for
a myriad instances and applications? To a philosopher all _news_, as it
is called, is gossip, and they who edit and read it are old women over
their tea. Yet not a few are greedy after this gossip. There was such a
rush, as I hear, the other day at one of the offices to learn the
foreign news by the last arrival, that several large squares of plate
glass belonging to the establishment were broken by the pressure,—news
which I seriously think a ready wit might write a twelve-month, or
twelve years, beforehand with sufficient accuracy. As for Spain, for
instance, if you know how to throw in Don Carlos and the Infanta, and
Don Pedro and Seville and Granada, from time to time in the right
proportions,—they may have changed the names a little since I saw the
papers,—and serve up a bull-fight when other entertainments fail, it
will be true to the letter, and give us as good an idea of the exact
state or ruin of things in Spain as the most succinct and lucid reports
under this head in the newspapers: and as for England, almost the last
significant scrap of news from that quarter was the revolution of 1649;
and if you have learned the history of her crops for an average year,
you never need attend to that thing again, unless your speculations are
of a merely pecuniary character. If one may judge who rarely looks into
the newspapers, nothing new does ever happen in foreign parts, a French
revolution not excepted.

What news! how much more important to know what that is which was never
old! “Kieou-he-yu (great dignitary of the state of Wei) sent a man to
Khoung-tseu to know his news. Khoung-tseu caused the messenger to be
seated near him, and questioned him in these terms: What is your master
doing? The messenger answered with respect: My master desires to
diminish the number of his faults, but he cannot come to the end of
them. The messenger being gone, the philosopher remarked: What a worthy
messenger! What a worthy messenger!” The preacher, instead of vexing
the ears of drowsy farmers on their day of rest at the end of the
week,—for Sunday is the fit conclusion of an ill-spent week, and not
the fresh and brave beginning of a new one,—with this one other
draggle-tail of a sermon, should shout with thundering voice, “Pause!
Avast! Why so seeming fast, but deadly slow?”

Shams and delusions are esteemed for soundest truths, while reality is
fabulous. If men would steadily observe realities only, and not allow
themselves to be deluded, life, to compare it with such things as we
know, would be like a fairy tale and the Arabian Nights’
Entertainments. If we respected only what is inevitable and has a right
to be, music and poetry would resound along the streets. When we are
unhurried and wise, we perceive that only great and worthy things have
any permanent and absolute existence,—that petty fears and petty
pleasures are but the shadow of the reality. This is always
exhilarating and sublime. By closing the eyes and slumbering, and
consenting to be deceived by shows, men establish and confirm their
daily life of routine and habit everywhere, which still is built on
purely illusory foundations. Children, who play life, discern its true
law and relations more clearly than men, who fail to live it worthily,
but who think that they are wiser by experience, that is, by failure. I
have read in a Hindoo book, that “there was a king’s son, who, being
expelled in infancy from his native city, was brought up by a forester,
and, growing up to maturity in that state, imagined himself to belong
to the barbarous race with which he lived. One of his father’s
ministers having discovered him, revealed to him what he was, and the
misconception of his character was removed, and he knew himself to be a
prince. So soul,” continues the Hindoo philosopher, “from the
circumstances in which it is placed, mistakes its own character, until
the truth is revealed to it by some holy teacher, and then it knows
itself to be _Brahme_.” I perceive that we inhabitants of New England
live this mean life that we do because our vision does not penetrate
the surface of things. We think that that _is_ which _appears_ to be.
If a man should walk through this town and see only the reality, where,
think you, would the “Mill-dam” go to? If he should give us an account
of the realities he beheld there, we should not recognize the place in
his description. Look at a meeting-house, or a court-house, or a jail,
or a shop, or a dwelling-house, and say what that thing really is
before a true gaze, and they would all go to pieces in your account of
them. Men esteem truth remote, in the outskirts of the system, behind
the farthest star, before Adam and after the last man. In eternity
there is indeed something true and sublime. But all these times and
places and occasions are now and here. God himself culminates in the
present moment, and will never be more divine in the lapse of all the
ages. And we are enabled to apprehend at all what is sublime and noble
only by the perpetual instilling and drenching of the reality that
surrounds us. The universe constantly and obediently answers to our
conceptions; whether we travel fast or slow, the track is laid for us.
Let us spend our lives in conceiving then. The poet or the artist never
yet had so fair and noble a design but some of his posterity at least
could accomplish it.

Let us spend one day as deliberately as Nature, and not be thrown off
the track by every nutshell and mosquito’s wing that falls on the
rails. Let us rise early and fast, or break fast, gently and without
perturbation; let company come and let company go, let the bells ring
and the children cry,—determined to make a day of it. Why should we
knock under and go with the stream? Let us not be upset and overwhelmed
in that terrible rapid and whirlpool called a dinner, situated in the
meridian shallows. Weather this danger and you are safe, for the rest
of the way is down hill. With unrelaxed nerves, with morning vigor,
sail by it, looking another way, tied to the mast like Ulysses. If the
engine whistles, let it whistle till it is hoarse for its pains. If the
bell rings, why should we run? We will consider what kind of music they
are like. Let us settle ourselves, and work and wedge our feet downward
through the mud and slush of opinion, and prejudice, and tradition, and
delusion, and appearance, that alluvion which covers the globe, through
Paris and London, through New York and Boston and Concord, through
church and state, through poetry and philosophy and religion, till we
come to a hard bottom and rocks in place, which we can call _reality_,
and say, This is, and no mistake; and then begin, having a _point
d’appui_, below freshet and frost and fire, a place where you might
found a wall or a state, or set a lamp-post safely, or perhaps a gauge,
not a Nilometer, but a Realometer, that future ages might know how deep
a freshet of shams and appearances had gathered from time to time. If
you stand right fronting and face to face to a fact, you will see the
sun glimmer on both its surfaces, as if it were a cimeter, and feel its
sweet edge dividing you through the heart and marrow, and so you will
happily conclude your mortal career. Be it life or death, we crave only
reality. If we are really dying, let us hear the rattle in our throats
and feel cold in the extremities; if we are alive, let us go about our
business.

Time is but the stream I go a-fishing in. I drink at it; but while I
drink I see the sandy bottom and detect how shallow it is. Its thin
current slides away, but eternity remains. I would drink deeper; fish
in the sky, whose bottom is pebbly with stars. I cannot count one. I
know not the first letter of the alphabet. I have always been
regretting that I was not as wise as the day I was born. The intellect
is a cleaver; it discerns and rifts its way into the secret of things.
I do not wish to be any more busy with my hands than is necessary. My
head is hands and feet. I feel all my best faculties concentrated in
it. My instinct tells me that my head is an organ for burrowing, as
some creatures use their snout and fore-paws, and with it I would mine
and burrow my way through these hills. I think that the richest vein is
somewhere hereabouts; so by the divining-rod and thin rising vapors I
judge; and here I will begin to mine.


